#define _vel_vld_vssl __builtin_ve_vl_vld_vssl
#define _vel_vld_vssvl __builtin_ve_vl_vld_vssvl
#define _vel_vldnc_vssl __builtin_ve_vl_vldnc_vssl
#define _vel_vldnc_vssvl __builtin_ve_vl_vldnc_vssvl
#define _vel_vldu_vssl __builtin_ve_vl_vldu_vssl
#define _vel_vldu_vssvl __builtin_ve_vl_vldu_vssvl
#define _vel_vldunc_vssl __builtin_ve_vl_vldunc_vssl
#define _vel_vldunc_vssvl __builtin_ve_vl_vldunc_vssvl
#define _vel_vldlsx_vssl __builtin_ve_vl_vldlsx_vssl
#define _vel_vldlsx_vssvl __builtin_ve_vl_vldlsx_vssvl
#define _vel_vldlsxnc_vssl __builtin_ve_vl_vldlsxnc_vssl
#define _vel_vldlsxnc_vssvl __builtin_ve_vl_vldlsxnc_vssvl
#define _vel_vldlzx_vssl __builtin_ve_vl_vldlzx_vssl
#define _vel_vldlzx_vssvl __builtin_ve_vl_vldlzx_vssvl
#define _vel_vldlzxnc_vssl __builtin_ve_vl_vldlzxnc_vssl
#define _vel_vldlzxnc_vssvl __builtin_ve_vl_vldlzxnc_vssvl
#define _vel_vld2d_vssl __builtin_ve_vl_vld2d_vssl
#define _vel_vld2d_vssvl __builtin_ve_vl_vld2d_vssvl
#define _vel_vld2dnc_vssl __builtin_ve_vl_vld2dnc_vssl
#define _vel_vld2dnc_vssvl __builtin_ve_vl_vld2dnc_vssvl
#define _vel_vldu2d_vssl __builtin_ve_vl_vldu2d_vssl
#define _vel_vldu2d_vssvl __builtin_ve_vl_vldu2d_vssvl
#define _vel_vldu2dnc_vssl __builtin_ve_vl_vldu2dnc_vssl
#define _vel_vldu2dnc_vssvl __builtin_ve_vl_vldu2dnc_vssvl
#define _vel_vldl2dsx_vssl __builtin_ve_vl_vldl2dsx_vssl
#define _vel_vldl2dsx_vssvl __builtin_ve_vl_vldl2dsx_vssvl
#define _vel_vldl2dsxnc_vssl __builtin_ve_vl_vldl2dsxnc_vssl
#define _vel_vldl2dsxnc_vssvl __builtin_ve_vl_vldl2dsxnc_vssvl
#define _vel_vldl2dzx_vssl __builtin_ve_vl_vldl2dzx_vssl
#define _vel_vldl2dzx_vssvl __builtin_ve_vl_vldl2dzx_vssvl
#define _vel_vldl2dzxnc_vssl __builtin_ve_vl_vldl2dzxnc_vssl
#define _vel_vldl2dzxnc_vssvl __builtin_ve_vl_vldl2dzxnc_vssvl
#define _vel_vst_vssl __builtin_ve_vl_vst_vssl
#define _vel_vst_vssml __builtin_ve_vl_vst_vssml
#define _vel_vstnc_vssl __builtin_ve_vl_vstnc_vssl
#define _vel_vstnc_vssml __builtin_ve_vl_vstnc_vssml
#define _vel_vstot_vssl __builtin_ve_vl_vstot_vssl
#define _vel_vstot_vssml __builtin_ve_vl_vstot_vssml
#define _vel_vstncot_vssl __builtin_ve_vl_vstncot_vssl
#define _vel_vstncot_vssml __builtin_ve_vl_vstncot_vssml
#define _vel_vstu_vssl __builtin_ve_vl_vstu_vssl
#define _vel_vstu_vssml __builtin_ve_vl_vstu_vssml
#define _vel_vstunc_vssl __builtin_ve_vl_vstunc_vssl
#define _vel_vstunc_vssml __builtin_ve_vl_vstunc_vssml
#define _vel_vstuot_vssl __builtin_ve_vl_vstuot_vssl
#define _vel_vstuot_vssml __builtin_ve_vl_vstuot_vssml
#define _vel_vstuncot_vssl __builtin_ve_vl_vstuncot_vssl
#define _vel_vstuncot_vssml __builtin_ve_vl_vstuncot_vssml
#define _vel_vstl_vssl __builtin_ve_vl_vstl_vssl
#define _vel_vstl_vssml __builtin_ve_vl_vstl_vssml
#define _vel_vstlnc_vssl __builtin_ve_vl_vstlnc_vssl
#define _vel_vstlnc_vssml __builtin_ve_vl_vstlnc_vssml
#define _vel_vstlot_vssl __builtin_ve_vl_vstlot_vssl
#define _vel_vstlot_vssml __builtin_ve_vl_vstlot_vssml
#define _vel_vstlncot_vssl __builtin_ve_vl_vstlncot_vssl
#define _vel_vstlncot_vssml __builtin_ve_vl_vstlncot_vssml
#define _vel_vst2d_vssl __builtin_ve_vl_vst2d_vssl
#define _vel_vst2d_vssml __builtin_ve_vl_vst2d_vssml
#define _vel_vst2dnc_vssl __builtin_ve_vl_vst2dnc_vssl
#define _vel_vst2dnc_vssml __builtin_ve_vl_vst2dnc_vssml
#define _vel_vst2dot_vssl __builtin_ve_vl_vst2dot_vssl
#define _vel_vst2dot_vssml __builtin_ve_vl_vst2dot_vssml
#define _vel_vst2dncot_vssl __builtin_ve_vl_vst2dncot_vssl
#define _vel_vst2dncot_vssml __builtin_ve_vl_vst2dncot_vssml
#define _vel_vstu2d_vssl __builtin_ve_vl_vstu2d_vssl
#define _vel_vstu2d_vssml __builtin_ve_vl_vstu2d_vssml
#define _vel_vstu2dnc_vssl __builtin_ve_vl_vstu2dnc_vssl
#define _vel_vstu2dnc_vssml __builtin_ve_vl_vstu2dnc_vssml
#define _vel_vstu2dot_vssl __builtin_ve_vl_vstu2dot_vssl
#define _vel_vstu2dot_vssml __builtin_ve_vl_vstu2dot_vssml
#define _vel_vstu2dncot_vssl __builtin_ve_vl_vstu2dncot_vssl
#define _vel_vstu2dncot_vssml __builtin_ve_vl_vstu2dncot_vssml
#define _vel_vstl2d_vssl __builtin_ve_vl_vstl2d_vssl
#define _vel_vstl2d_vssml __builtin_ve_vl_vstl2d_vssml
#define _vel_vstl2dnc_vssl __builtin_ve_vl_vstl2dnc_vssl
#define _vel_vstl2dnc_vssml __builtin_ve_vl_vstl2dnc_vssml
#define _vel_vstl2dot_vssl __builtin_ve_vl_vstl2dot_vssl
#define _vel_vstl2dot_vssml __builtin_ve_vl_vstl2dot_vssml
#define _vel_vstl2dncot_vssl __builtin_ve_vl_vstl2dncot_vssl
#define _vel_vstl2dncot_vssml __builtin_ve_vl_vstl2dncot_vssml
#define _vel_pfchv_ssl __builtin_ve_vl_pfchv_ssl
#define _vel_pfchvnc_ssl __builtin_ve_vl_pfchvnc_ssl
#define _vel_lsv_vvss __builtin_ve_vl_lsv_vvss
#define _vel_lvsl_svs __builtin_ve_vl_lvsl_svs
#define _vel_lvsd_svs __builtin_ve_vl_lvsd_svs
#define _vel_lvss_svs __builtin_ve_vl_lvss_svs
#define _vel_lvm_mmss __builtin_ve_vl_lvm_mmss
#define _vel_lvm_MMss __builtin_ve_vl_lvm_MMss
#define _vel_svm_sms __builtin_ve_vl_svm_sms
#define _vel_svm_sMs __builtin_ve_vl_svm_sMs
#define _vel_vbrdd_vsl __builtin_ve_vl_vbrdd_vsl
#define _vel_vbrdd_vsvl __builtin_ve_vl_vbrdd_vsvl
#define _vel_vbrdd_vsmvl __builtin_ve_vl_vbrdd_vsmvl
#define _vel_vbrdl_vsl __builtin_ve_vl_vbrdl_vsl
#define _vel_vbrdl_vsvl __builtin_ve_vl_vbrdl_vsvl
#define _vel_vbrdl_vsmvl __builtin_ve_vl_vbrdl_vsmvl
#define _vel_vbrds_vsl __builtin_ve_vl_vbrds_vsl
#define _vel_vbrds_vsvl __builtin_ve_vl_vbrds_vsvl
#define _vel_vbrds_vsmvl __builtin_ve_vl_vbrds_vsmvl
#define _vel_vbrdw_vsl __builtin_ve_vl_vbrdw_vsl
#define _vel_vbrdw_vsvl __builtin_ve_vl_vbrdw_vsvl
#define _vel_vbrdw_vsmvl __builtin_ve_vl_vbrdw_vsmvl
#define _vel_pvbrd_vsl __builtin_ve_vl_pvbrd_vsl
#define _vel_pvbrd_vsvl __builtin_ve_vl_pvbrd_vsvl
#define _vel_pvbrd_vsMvl __builtin_ve_vl_pvbrd_vsMvl
#define _vel_vmv_vsvl __builtin_ve_vl_vmv_vsvl
#define _vel_vmv_vsvvl __builtin_ve_vl_vmv_vsvvl
#define _vel_vmv_vsvmvl __builtin_ve_vl_vmv_vsvmvl
#define _vel_vaddul_vvvl __builtin_ve_vl_vaddul_vvvl
#define _vel_vaddul_vvvvl __builtin_ve_vl_vaddul_vvvvl
#define _vel_vaddul_vsvl __builtin_ve_vl_vaddul_vsvl
#define _vel_vaddul_vsvvl __builtin_ve_vl_vaddul_vsvvl
#define _vel_vaddul_vvvmvl __builtin_ve_vl_vaddul_vvvmvl
#define _vel_vaddul_vsvmvl __builtin_ve_vl_vaddul_vsvmvl
#define _vel_vadduw_vvvl __builtin_ve_vl_vadduw_vvvl
#define _vel_vadduw_vvvvl __builtin_ve_vl_vadduw_vvvvl
#define _vel_vadduw_vsvl __builtin_ve_vl_vadduw_vsvl
#define _vel_vadduw_vsvvl __builtin_ve_vl_vadduw_vsvvl
#define _vel_vadduw_vvvmvl __builtin_ve_vl_vadduw_vvvmvl
#define _vel_vadduw_vsvmvl __builtin_ve_vl_vadduw_vsvmvl
#define _vel_pvaddu_vvvl __builtin_ve_vl_pvaddu_vvvl
#define _vel_pvaddu_vvvvl __builtin_ve_vl_pvaddu_vvvvl
#define _vel_pvaddu_vsvl __builtin_ve_vl_pvaddu_vsvl
#define _vel_pvaddu_vsvvl __builtin_ve_vl_pvaddu_vsvvl
#define _vel_pvaddu_vvvMvl __builtin_ve_vl_pvaddu_vvvMvl
#define _vel_pvaddu_vsvMvl __builtin_ve_vl_pvaddu_vsvMvl
#define _vel_vaddswsx_vvvl __builtin_ve_vl_vaddswsx_vvvl
#define _vel_vaddswsx_vvvvl __builtin_ve_vl_vaddswsx_vvvvl
#define _vel_vaddswsx_vsvl __builtin_ve_vl_vaddswsx_vsvl
#define _vel_vaddswsx_vsvvl __builtin_ve_vl_vaddswsx_vsvvl
#define _vel_vaddswsx_vvvmvl __builtin_ve_vl_vaddswsx_vvvmvl
#define _vel_vaddswsx_vsvmvl __builtin_ve_vl_vaddswsx_vsvmvl
#define _vel_vaddswzx_vvvl __builtin_ve_vl_vaddswzx_vvvl
#define _vel_vaddswzx_vvvvl __builtin_ve_vl_vaddswzx_vvvvl
#define _vel_vaddswzx_vsvl __builtin_ve_vl_vaddswzx_vsvl
#define _vel_vaddswzx_vsvvl __builtin_ve_vl_vaddswzx_vsvvl
#define _vel_vaddswzx_vvvmvl __builtin_ve_vl_vaddswzx_vvvmvl
#define _vel_vaddswzx_vsvmvl __builtin_ve_vl_vaddswzx_vsvmvl
#define _vel_pvadds_vvvl __builtin_ve_vl_pvadds_vvvl
#define _vel_pvadds_vvvvl __builtin_ve_vl_pvadds_vvvvl
#define _vel_pvadds_vsvl __builtin_ve_vl_pvadds_vsvl
#define _vel_pvadds_vsvvl __builtin_ve_vl_pvadds_vsvvl
#define _vel_pvadds_vvvMvl __builtin_ve_vl_pvadds_vvvMvl
#define _vel_pvadds_vsvMvl __builtin_ve_vl_pvadds_vsvMvl
#define _vel_vaddsl_vvvl __builtin_ve_vl_vaddsl_vvvl
#define _vel_vaddsl_vvvvl __builtin_ve_vl_vaddsl_vvvvl
#define _vel_vaddsl_vsvl __builtin_ve_vl_vaddsl_vsvl
#define _vel_vaddsl_vsvvl __builtin_ve_vl_vaddsl_vsvvl
#define _vel_vaddsl_vvvmvl __builtin_ve_vl_vaddsl_vvvmvl
#define _vel_vaddsl_vsvmvl __builtin_ve_vl_vaddsl_vsvmvl
#define _vel_vsubul_vvvl __builtin_ve_vl_vsubul_vvvl
#define _vel_vsubul_vvvvl __builtin_ve_vl_vsubul_vvvvl
#define _vel_vsubul_vsvl __builtin_ve_vl_vsubul_vsvl
#define _vel_vsubul_vsvvl __builtin_ve_vl_vsubul_vsvvl
#define _vel_vsubul_vvvmvl __builtin_ve_vl_vsubul_vvvmvl
#define _vel_vsubul_vsvmvl __builtin_ve_vl_vsubul_vsvmvl
#define _vel_vsubuw_vvvl __builtin_ve_vl_vsubuw_vvvl
#define _vel_vsubuw_vvvvl __builtin_ve_vl_vsubuw_vvvvl
#define _vel_vsubuw_vsvl __builtin_ve_vl_vsubuw_vsvl
#define _vel_vsubuw_vsvvl __builtin_ve_vl_vsubuw_vsvvl
#define _vel_vsubuw_vvvmvl __builtin_ve_vl_vsubuw_vvvmvl
#define _vel_vsubuw_vsvmvl __builtin_ve_vl_vsubuw_vsvmvl
#define _vel_pvsubu_vvvl __builtin_ve_vl_pvsubu_vvvl
#define _vel_pvsubu_vvvvl __builtin_ve_vl_pvsubu_vvvvl
#define _vel_pvsubu_vsvl __builtin_ve_vl_pvsubu_vsvl
#define _vel_pvsubu_vsvvl __builtin_ve_vl_pvsubu_vsvvl
#define _vel_pvsubu_vvvMvl __builtin_ve_vl_pvsubu_vvvMvl
#define _vel_pvsubu_vsvMvl __builtin_ve_vl_pvsubu_vsvMvl
#define _vel_vsubswsx_vvvl __builtin_ve_vl_vsubswsx_vvvl
#define _vel_vsubswsx_vvvvl __builtin_ve_vl_vsubswsx_vvvvl
#define _vel_vsubswsx_vsvl __builtin_ve_vl_vsubswsx_vsvl
#define _vel_vsubswsx_vsvvl __builtin_ve_vl_vsubswsx_vsvvl
#define _vel_vsubswsx_vvvmvl __builtin_ve_vl_vsubswsx_vvvmvl
#define _vel_vsubswsx_vsvmvl __builtin_ve_vl_vsubswsx_vsvmvl
#define _vel_vsubswzx_vvvl __builtin_ve_vl_vsubswzx_vvvl
#define _vel_vsubswzx_vvvvl __builtin_ve_vl_vsubswzx_vvvvl
#define _vel_vsubswzx_vsvl __builtin_ve_vl_vsubswzx_vsvl
#define _vel_vsubswzx_vsvvl __builtin_ve_vl_vsubswzx_vsvvl
#define _vel_vsubswzx_vvvmvl __builtin_ve_vl_vsubswzx_vvvmvl
#define _vel_vsubswzx_vsvmvl __builtin_ve_vl_vsubswzx_vsvmvl
#define _vel_pvsubs_vvvl __builtin_ve_vl_pvsubs_vvvl
#define _vel_pvsubs_vvvvl __builtin_ve_vl_pvsubs_vvvvl
#define _vel_pvsubs_vsvl __builtin_ve_vl_pvsubs_vsvl
#define _vel_pvsubs_vsvvl __builtin_ve_vl_pvsubs_vsvvl
#define _vel_pvsubs_vvvMvl __builtin_ve_vl_pvsubs_vvvMvl
#define _vel_pvsubs_vsvMvl __builtin_ve_vl_pvsubs_vsvMvl
#define _vel_vsubsl_vvvl __builtin_ve_vl_vsubsl_vvvl
#define _vel_vsubsl_vvvvl __builtin_ve_vl_vsubsl_vvvvl
#define _vel_vsubsl_vsvl __builtin_ve_vl_vsubsl_vsvl
#define _vel_vsubsl_vsvvl __builtin_ve_vl_vsubsl_vsvvl
#define _vel_vsubsl_vvvmvl __builtin_ve_vl_vsubsl_vvvmvl
#define _vel_vsubsl_vsvmvl __builtin_ve_vl_vsubsl_vsvmvl
#define _vel_vmulul_vvvl __builtin_ve_vl_vmulul_vvvl
#define _vel_vmulul_vvvvl __builtin_ve_vl_vmulul_vvvvl
#define _vel_vmulul_vsvl __builtin_ve_vl_vmulul_vsvl
#define _vel_vmulul_vsvvl __builtin_ve_vl_vmulul_vsvvl
#define _vel_vmulul_vvvmvl __builtin_ve_vl_vmulul_vvvmvl
#define _vel_vmulul_vsvmvl __builtin_ve_vl_vmulul_vsvmvl
#define _vel_vmuluw_vvvl __builtin_ve_vl_vmuluw_vvvl
#define _vel_vmuluw_vvvvl __builtin_ve_vl_vmuluw_vvvvl
#define _vel_vmuluw_vsvl __builtin_ve_vl_vmuluw_vsvl
#define _vel_vmuluw_vsvvl __builtin_ve_vl_vmuluw_vsvvl
#define _vel_vmuluw_vvvmvl __builtin_ve_vl_vmuluw_vvvmvl
#define _vel_vmuluw_vsvmvl __builtin_ve_vl_vmuluw_vsvmvl
#define _vel_vmulswsx_vvvl __builtin_ve_vl_vmulswsx_vvvl
#define _vel_vmulswsx_vvvvl __builtin_ve_vl_vmulswsx_vvvvl
#define _vel_vmulswsx_vsvl __builtin_ve_vl_vmulswsx_vsvl
#define _vel_vmulswsx_vsvvl __builtin_ve_vl_vmulswsx_vsvvl
#define _vel_vmulswsx_vvvmvl __builtin_ve_vl_vmulswsx_vvvmvl
#define _vel_vmulswsx_vsvmvl __builtin_ve_vl_vmulswsx_vsvmvl
#define _vel_vmulswzx_vvvl __builtin_ve_vl_vmulswzx_vvvl
#define _vel_vmulswzx_vvvvl __builtin_ve_vl_vmulswzx_vvvvl
#define _vel_vmulswzx_vsvl __builtin_ve_vl_vmulswzx_vsvl
#define _vel_vmulswzx_vsvvl __builtin_ve_vl_vmulswzx_vsvvl
#define _vel_vmulswzx_vvvmvl __builtin_ve_vl_vmulswzx_vvvmvl
#define _vel_vmulswzx_vsvmvl __builtin_ve_vl_vmulswzx_vsvmvl
#define _vel_vmulsl_vvvl __builtin_ve_vl_vmulsl_vvvl
#define _vel_vmulsl_vvvvl __builtin_ve_vl_vmulsl_vvvvl
#define _vel_vmulsl_vsvl __builtin_ve_vl_vmulsl_vsvl
#define _vel_vmulsl_vsvvl __builtin_ve_vl_vmulsl_vsvvl
#define _vel_vmulsl_vvvmvl __builtin_ve_vl_vmulsl_vvvmvl
#define _vel_vmulsl_vsvmvl __builtin_ve_vl_vmulsl_vsvmvl
#define _vel_vmulslw_vvvl __builtin_ve_vl_vmulslw_vvvl
#define _vel_vmulslw_vvvvl __builtin_ve_vl_vmulslw_vvvvl
#define _vel_vmulslw_vsvl __builtin_ve_vl_vmulslw_vsvl
#define _vel_vmulslw_vsvvl __builtin_ve_vl_vmulslw_vsvvl
#define _vel_vdivul_vvvl __builtin_ve_vl_vdivul_vvvl
#define _vel_vdivul_vvvvl __builtin_ve_vl_vdivul_vvvvl
#define _vel_vdivul_vsvl __builtin_ve_vl_vdivul_vsvl
#define _vel_vdivul_vsvvl __builtin_ve_vl_vdivul_vsvvl
#define _vel_vdivul_vvvmvl __builtin_ve_vl_vdivul_vvvmvl
#define _vel_vdivul_vsvmvl __builtin_ve_vl_vdivul_vsvmvl
#define _vel_vdivuw_vvvl __builtin_ve_vl_vdivuw_vvvl
#define _vel_vdivuw_vvvvl __builtin_ve_vl_vdivuw_vvvvl
#define _vel_vdivuw_vsvl __builtin_ve_vl_vdivuw_vsvl
#define _vel_vdivuw_vsvvl __builtin_ve_vl_vdivuw_vsvvl
#define _vel_vdivuw_vvvmvl __builtin_ve_vl_vdivuw_vvvmvl
#define _vel_vdivuw_vsvmvl __builtin_ve_vl_vdivuw_vsvmvl
#define _vel_vdivul_vvsl __builtin_ve_vl_vdivul_vvsl
#define _vel_vdivul_vvsvl __builtin_ve_vl_vdivul_vvsvl
#define _vel_vdivul_vvsmvl __builtin_ve_vl_vdivul_vvsmvl
#define _vel_vdivuw_vvsl __builtin_ve_vl_vdivuw_vvsl
#define _vel_vdivuw_vvsvl __builtin_ve_vl_vdivuw_vvsvl
#define _vel_vdivuw_vvsmvl __builtin_ve_vl_vdivuw_vvsmvl
#define _vel_vdivswsx_vvvl __builtin_ve_vl_vdivswsx_vvvl
#define _vel_vdivswsx_vvvvl __builtin_ve_vl_vdivswsx_vvvvl
#define _vel_vdivswsx_vsvl __builtin_ve_vl_vdivswsx_vsvl
#define _vel_vdivswsx_vsvvl __builtin_ve_vl_vdivswsx_vsvvl
#define _vel_vdivswsx_vvvmvl __builtin_ve_vl_vdivswsx_vvvmvl
#define _vel_vdivswsx_vsvmvl __builtin_ve_vl_vdivswsx_vsvmvl
#define _vel_vdivswzx_vvvl __builtin_ve_vl_vdivswzx_vvvl
#define _vel_vdivswzx_vvvvl __builtin_ve_vl_vdivswzx_vvvvl
#define _vel_vdivswzx_vsvl __builtin_ve_vl_vdivswzx_vsvl
#define _vel_vdivswzx_vsvvl __builtin_ve_vl_vdivswzx_vsvvl
#define _vel_vdivswzx_vvvmvl __builtin_ve_vl_vdivswzx_vvvmvl
#define _vel_vdivswzx_vsvmvl __builtin_ve_vl_vdivswzx_vsvmvl
#define _vel_vdivswsx_vvsl __builtin_ve_vl_vdivswsx_vvsl
#define _vel_vdivswsx_vvsvl __builtin_ve_vl_vdivswsx_vvsvl
#define _vel_vdivswsx_vvsmvl __builtin_ve_vl_vdivswsx_vvsmvl
#define _vel_vdivswzx_vvsl __builtin_ve_vl_vdivswzx_vvsl
#define _vel_vdivswzx_vvsvl __builtin_ve_vl_vdivswzx_vvsvl
#define _vel_vdivswzx_vvsmvl __builtin_ve_vl_vdivswzx_vvsmvl
#define _vel_vdivsl_vvvl __builtin_ve_vl_vdivsl_vvvl
#define _vel_vdivsl_vvvvl __builtin_ve_vl_vdivsl_vvvvl
#define _vel_vdivsl_vsvl __builtin_ve_vl_vdivsl_vsvl
#define _vel_vdivsl_vsvvl __builtin_ve_vl_vdivsl_vsvvl
#define _vel_vdivsl_vvvmvl __builtin_ve_vl_vdivsl_vvvmvl
#define _vel_vdivsl_vsvmvl __builtin_ve_vl_vdivsl_vsvmvl
#define _vel_vdivsl_vvsl __builtin_ve_vl_vdivsl_vvsl
#define _vel_vdivsl_vvsvl __builtin_ve_vl_vdivsl_vvsvl
#define _vel_vdivsl_vvsmvl __builtin_ve_vl_vdivsl_vvsmvl
#define _vel_vcmpul_vvvl __builtin_ve_vl_vcmpul_vvvl
#define _vel_vcmpul_vvvvl __builtin_ve_vl_vcmpul_vvvvl
#define _vel_vcmpul_vsvl __builtin_ve_vl_vcmpul_vsvl
#define _vel_vcmpul_vsvvl __builtin_ve_vl_vcmpul_vsvvl
#define _vel_vcmpul_vvvmvl __builtin_ve_vl_vcmpul_vvvmvl
#define _vel_vcmpul_vsvmvl __builtin_ve_vl_vcmpul_vsvmvl
#define _vel_vcmpuw_vvvl __builtin_ve_vl_vcmpuw_vvvl
#define _vel_vcmpuw_vvvvl __builtin_ve_vl_vcmpuw_vvvvl
#define _vel_vcmpuw_vsvl __builtin_ve_vl_vcmpuw_vsvl
#define _vel_vcmpuw_vsvvl __builtin_ve_vl_vcmpuw_vsvvl
#define _vel_vcmpuw_vvvmvl __builtin_ve_vl_vcmpuw_vvvmvl
#define _vel_vcmpuw_vsvmvl __builtin_ve_vl_vcmpuw_vsvmvl
#define _vel_pvcmpu_vvvl __builtin_ve_vl_pvcmpu_vvvl
#define _vel_pvcmpu_vvvvl __builtin_ve_vl_pvcmpu_vvvvl
#define _vel_pvcmpu_vsvl __builtin_ve_vl_pvcmpu_vsvl
#define _vel_pvcmpu_vsvvl __builtin_ve_vl_pvcmpu_vsvvl
#define _vel_pvcmpu_vvvMvl __builtin_ve_vl_pvcmpu_vvvMvl
#define _vel_pvcmpu_vsvMvl __builtin_ve_vl_pvcmpu_vsvMvl
#define _vel_vcmpswsx_vvvl __builtin_ve_vl_vcmpswsx_vvvl
#define _vel_vcmpswsx_vvvvl __builtin_ve_vl_vcmpswsx_vvvvl
#define _vel_vcmpswsx_vsvl __builtin_ve_vl_vcmpswsx_vsvl
#define _vel_vcmpswsx_vsvvl __builtin_ve_vl_vcmpswsx_vsvvl
#define _vel_vcmpswsx_vvvmvl __builtin_ve_vl_vcmpswsx_vvvmvl
#define _vel_vcmpswsx_vsvmvl __builtin_ve_vl_vcmpswsx_vsvmvl
#define _vel_vcmpswzx_vvvl __builtin_ve_vl_vcmpswzx_vvvl
#define _vel_vcmpswzx_vvvvl __builtin_ve_vl_vcmpswzx_vvvvl
#define _vel_vcmpswzx_vsvl __builtin_ve_vl_vcmpswzx_vsvl
#define _vel_vcmpswzx_vsvvl __builtin_ve_vl_vcmpswzx_vsvvl
#define _vel_vcmpswzx_vvvmvl __builtin_ve_vl_vcmpswzx_vvvmvl
#define _vel_vcmpswzx_vsvmvl __builtin_ve_vl_vcmpswzx_vsvmvl
#define _vel_pvcmps_vvvl __builtin_ve_vl_pvcmps_vvvl
#define _vel_pvcmps_vvvvl __builtin_ve_vl_pvcmps_vvvvl
#define _vel_pvcmps_vsvl __builtin_ve_vl_pvcmps_vsvl
#define _vel_pvcmps_vsvvl __builtin_ve_vl_pvcmps_vsvvl
#define _vel_pvcmps_vvvMvl __builtin_ve_vl_pvcmps_vvvMvl
#define _vel_pvcmps_vsvMvl __builtin_ve_vl_pvcmps_vsvMvl
#define _vel_vcmpsl_vvvl __builtin_ve_vl_vcmpsl_vvvl
#define _vel_vcmpsl_vvvvl __builtin_ve_vl_vcmpsl_vvvvl
#define _vel_vcmpsl_vsvl __builtin_ve_vl_vcmpsl_vsvl
#define _vel_vcmpsl_vsvvl __builtin_ve_vl_vcmpsl_vsvvl
#define _vel_vcmpsl_vvvmvl __builtin_ve_vl_vcmpsl_vvvmvl
#define _vel_vcmpsl_vsvmvl __builtin_ve_vl_vcmpsl_vsvmvl
#define _vel_vmaxswsx_vvvl __builtin_ve_vl_vmaxswsx_vvvl
#define _vel_vmaxswsx_vvvvl __builtin_ve_vl_vmaxswsx_vvvvl
#define _vel_vmaxswsx_vsvl __builtin_ve_vl_vmaxswsx_vsvl
#define _vel_vmaxswsx_vsvvl __builtin_ve_vl_vmaxswsx_vsvvl
#define _vel_vmaxswsx_vvvmvl __builtin_ve_vl_vmaxswsx_vvvmvl
#define _vel_vmaxswsx_vsvmvl __builtin_ve_vl_vmaxswsx_vsvmvl
#define _vel_vmaxswzx_vvvl __builtin_ve_vl_vmaxswzx_vvvl
#define _vel_vmaxswzx_vvvvl __builtin_ve_vl_vmaxswzx_vvvvl
#define _vel_vmaxswzx_vsvl __builtin_ve_vl_vmaxswzx_vsvl
#define _vel_vmaxswzx_vsvvl __builtin_ve_vl_vmaxswzx_vsvvl
#define _vel_vmaxswzx_vvvmvl __builtin_ve_vl_vmaxswzx_vvvmvl
#define _vel_vmaxswzx_vsvmvl __builtin_ve_vl_vmaxswzx_vsvmvl
#define _vel_pvmaxs_vvvl __builtin_ve_vl_pvmaxs_vvvl
#define _vel_pvmaxs_vvvvl __builtin_ve_vl_pvmaxs_vvvvl
#define _vel_pvmaxs_vsvl __builtin_ve_vl_pvmaxs_vsvl
#define _vel_pvmaxs_vsvvl __builtin_ve_vl_pvmaxs_vsvvl
#define _vel_pvmaxs_vvvMvl __builtin_ve_vl_pvmaxs_vvvMvl
#define _vel_pvmaxs_vsvMvl __builtin_ve_vl_pvmaxs_vsvMvl
#define _vel_vminswsx_vvvl __builtin_ve_vl_vminswsx_vvvl
#define _vel_vminswsx_vvvvl __builtin_ve_vl_vminswsx_vvvvl
#define _vel_vminswsx_vsvl __builtin_ve_vl_vminswsx_vsvl
#define _vel_vminswsx_vsvvl __builtin_ve_vl_vminswsx_vsvvl
#define _vel_vminswsx_vvvmvl __builtin_ve_vl_vminswsx_vvvmvl
#define _vel_vminswsx_vsvmvl __builtin_ve_vl_vminswsx_vsvmvl
#define _vel_vminswzx_vvvl __builtin_ve_vl_vminswzx_vvvl
#define _vel_vminswzx_vvvvl __builtin_ve_vl_vminswzx_vvvvl
#define _vel_vminswzx_vsvl __builtin_ve_vl_vminswzx_vsvl
#define _vel_vminswzx_vsvvl __builtin_ve_vl_vminswzx_vsvvl
#define _vel_vminswzx_vvvmvl __builtin_ve_vl_vminswzx_vvvmvl
#define _vel_vminswzx_vsvmvl __builtin_ve_vl_vminswzx_vsvmvl
#define _vel_pvmins_vvvl __builtin_ve_vl_pvmins_vvvl
#define _vel_pvmins_vvvvl __builtin_ve_vl_pvmins_vvvvl
#define _vel_pvmins_vsvl __builtin_ve_vl_pvmins_vsvl
#define _vel_pvmins_vsvvl __builtin_ve_vl_pvmins_vsvvl
#define _vel_pvmins_vvvMvl __builtin_ve_vl_pvmins_vvvMvl
#define _vel_pvmins_vsvMvl __builtin_ve_vl_pvmins_vsvMvl
#define _vel_vmaxsl_vvvl __builtin_ve_vl_vmaxsl_vvvl
#define _vel_vmaxsl_vvvvl __builtin_ve_vl_vmaxsl_vvvvl
#define _vel_vmaxsl_vsvl __builtin_ve_vl_vmaxsl_vsvl
#define _vel_vmaxsl_vsvvl __builtin_ve_vl_vmaxsl_vsvvl
#define _vel_vmaxsl_vvvmvl __builtin_ve_vl_vmaxsl_vvvmvl
#define _vel_vmaxsl_vsvmvl __builtin_ve_vl_vmaxsl_vsvmvl
#define _vel_vminsl_vvvl __builtin_ve_vl_vminsl_vvvl
#define _vel_vminsl_vvvvl __builtin_ve_vl_vminsl_vvvvl
#define _vel_vminsl_vsvl __builtin_ve_vl_vminsl_vsvl
#define _vel_vminsl_vsvvl __builtin_ve_vl_vminsl_vsvvl
#define _vel_vminsl_vvvmvl __builtin_ve_vl_vminsl_vvvmvl
#define _vel_vminsl_vsvmvl __builtin_ve_vl_vminsl_vsvmvl
#define _vel_vand_vvvl __builtin_ve_vl_vand_vvvl
#define _vel_vand_vvvvl __builtin_ve_vl_vand_vvvvl
#define _vel_vand_vsvl __builtin_ve_vl_vand_vsvl
#define _vel_vand_vsvvl __builtin_ve_vl_vand_vsvvl
#define _vel_vand_vvvmvl __builtin_ve_vl_vand_vvvmvl
#define _vel_vand_vsvmvl __builtin_ve_vl_vand_vsvmvl
#define _vel_pvand_vvvl __builtin_ve_vl_pvand_vvvl
#define _vel_pvand_vvvvl __builtin_ve_vl_pvand_vvvvl
#define _vel_pvand_vsvl __builtin_ve_vl_pvand_vsvl
#define _vel_pvand_vsvvl __builtin_ve_vl_pvand_vsvvl
#define _vel_pvand_vvvMvl __builtin_ve_vl_pvand_vvvMvl
#define _vel_pvand_vsvMvl __builtin_ve_vl_pvand_vsvMvl
#define _vel_vor_vvvl __builtin_ve_vl_vor_vvvl
#define _vel_vor_vvvvl __builtin_ve_vl_vor_vvvvl
#define _vel_vor_vsvl __builtin_ve_vl_vor_vsvl
#define _vel_vor_vsvvl __builtin_ve_vl_vor_vsvvl
#define _vel_vor_vvvmvl __builtin_ve_vl_vor_vvvmvl
#define _vel_vor_vsvmvl __builtin_ve_vl_vor_vsvmvl
#define _vel_pvor_vvvl __builtin_ve_vl_pvor_vvvl
#define _vel_pvor_vvvvl __builtin_ve_vl_pvor_vvvvl
#define _vel_pvor_vsvl __builtin_ve_vl_pvor_vsvl
#define _vel_pvor_vsvvl __builtin_ve_vl_pvor_vsvvl
#define _vel_pvor_vvvMvl __builtin_ve_vl_pvor_vvvMvl
#define _vel_pvor_vsvMvl __builtin_ve_vl_pvor_vsvMvl
#define _vel_vxor_vvvl __builtin_ve_vl_vxor_vvvl
#define _vel_vxor_vvvvl __builtin_ve_vl_vxor_vvvvl
#define _vel_vxor_vsvl __builtin_ve_vl_vxor_vsvl
#define _vel_vxor_vsvvl __builtin_ve_vl_vxor_vsvvl
#define _vel_vxor_vvvmvl __builtin_ve_vl_vxor_vvvmvl
#define _vel_vxor_vsvmvl __builtin_ve_vl_vxor_vsvmvl
#define _vel_pvxor_vvvl __builtin_ve_vl_pvxor_vvvl
#define _vel_pvxor_vvvvl __builtin_ve_vl_pvxor_vvvvl
#define _vel_pvxor_vsvl __builtin_ve_vl_pvxor_vsvl
#define _vel_pvxor_vsvvl __builtin_ve_vl_pvxor_vsvvl
#define _vel_pvxor_vvvMvl __builtin_ve_vl_pvxor_vvvMvl
#define _vel_pvxor_vsvMvl __builtin_ve_vl_pvxor_vsvMvl
#define _vel_veqv_vvvl __builtin_ve_vl_veqv_vvvl
#define _vel_veqv_vvvvl __builtin_ve_vl_veqv_vvvvl
#define _vel_veqv_vsvl __builtin_ve_vl_veqv_vsvl
#define _vel_veqv_vsvvl __builtin_ve_vl_veqv_vsvvl
#define _vel_veqv_vvvmvl __builtin_ve_vl_veqv_vvvmvl
#define _vel_veqv_vsvmvl __builtin_ve_vl_veqv_vsvmvl
#define _vel_pveqv_vvvl __builtin_ve_vl_pveqv_vvvl
#define _vel_pveqv_vvvvl __builtin_ve_vl_pveqv_vvvvl
#define _vel_pveqv_vsvl __builtin_ve_vl_pveqv_vsvl
#define _vel_pveqv_vsvvl __builtin_ve_vl_pveqv_vsvvl
#define _vel_pveqv_vvvMvl __builtin_ve_vl_pveqv_vvvMvl
#define _vel_pveqv_vsvMvl __builtin_ve_vl_pveqv_vsvMvl
#define _vel_vldz_vvl __builtin_ve_vl_vldz_vvl
#define _vel_vldz_vvvl __builtin_ve_vl_vldz_vvvl
#define _vel_vldz_vvmvl __builtin_ve_vl_vldz_vvmvl
#define _vel_pvldzlo_vvl __builtin_ve_vl_pvldzlo_vvl
#define _vel_pvldzlo_vvvl __builtin_ve_vl_pvldzlo_vvvl
#define _vel_pvldzlo_vvmvl __builtin_ve_vl_pvldzlo_vvmvl
#define _vel_pvldzup_vvl __builtin_ve_vl_pvldzup_vvl
#define _vel_pvldzup_vvvl __builtin_ve_vl_pvldzup_vvvl
#define _vel_pvldzup_vvmvl __builtin_ve_vl_pvldzup_vvmvl
#define _vel_pvldz_vvl __builtin_ve_vl_pvldz_vvl
#define _vel_pvldz_vvvl __builtin_ve_vl_pvldz_vvvl
#define _vel_pvldz_vvMvl __builtin_ve_vl_pvldz_vvMvl
#define _vel_vpcnt_vvl __builtin_ve_vl_vpcnt_vvl
#define _vel_vpcnt_vvvl __builtin_ve_vl_vpcnt_vvvl
#define _vel_vpcnt_vvmvl __builtin_ve_vl_vpcnt_vvmvl
#define _vel_pvpcntlo_vvl __builtin_ve_vl_pvpcntlo_vvl
#define _vel_pvpcntlo_vvvl __builtin_ve_vl_pvpcntlo_vvvl
#define _vel_pvpcntlo_vvmvl __builtin_ve_vl_pvpcntlo_vvmvl
#define _vel_pvpcntup_vvl __builtin_ve_vl_pvpcntup_vvl
#define _vel_pvpcntup_vvvl __builtin_ve_vl_pvpcntup_vvvl
#define _vel_pvpcntup_vvmvl __builtin_ve_vl_pvpcntup_vvmvl
#define _vel_pvpcnt_vvl __builtin_ve_vl_pvpcnt_vvl
#define _vel_pvpcnt_vvvl __builtin_ve_vl_pvpcnt_vvvl
#define _vel_pvpcnt_vvMvl __builtin_ve_vl_pvpcnt_vvMvl
#define _vel_vbrv_vvl __builtin_ve_vl_vbrv_vvl
#define _vel_vbrv_vvvl __builtin_ve_vl_vbrv_vvvl
#define _vel_vbrv_vvmvl __builtin_ve_vl_vbrv_vvmvl
#define _vel_pvbrvlo_vvl __builtin_ve_vl_pvbrvlo_vvl
#define _vel_pvbrvlo_vvvl __builtin_ve_vl_pvbrvlo_vvvl
#define _vel_pvbrvlo_vvmvl __builtin_ve_vl_pvbrvlo_vvmvl
#define _vel_pvbrvup_vvl __builtin_ve_vl_pvbrvup_vvl
#define _vel_pvbrvup_vvvl __builtin_ve_vl_pvbrvup_vvvl
#define _vel_pvbrvup_vvmvl __builtin_ve_vl_pvbrvup_vvmvl
#define _vel_pvbrv_vvl __builtin_ve_vl_pvbrv_vvl
#define _vel_pvbrv_vvvl __builtin_ve_vl_pvbrv_vvvl
#define _vel_pvbrv_vvMvl __builtin_ve_vl_pvbrv_vvMvl
#define _vel_vseq_vl __builtin_ve_vl_vseq_vl
#define _vel_vseq_vvl __builtin_ve_vl_vseq_vvl
#define _vel_pvseqlo_vl __builtin_ve_vl_pvseqlo_vl
#define _vel_pvseqlo_vvl __builtin_ve_vl_pvseqlo_vvl
#define _vel_pvsequp_vl __builtin_ve_vl_pvsequp_vl
#define _vel_pvsequp_vvl __builtin_ve_vl_pvsequp_vvl
#define _vel_pvseq_vl __builtin_ve_vl_pvseq_vl
#define _vel_pvseq_vvl __builtin_ve_vl_pvseq_vvl
#define _vel_vsll_vvvl __builtin_ve_vl_vsll_vvvl
#define _vel_vsll_vvvvl __builtin_ve_vl_vsll_vvvvl
#define _vel_vsll_vvsl __builtin_ve_vl_vsll_vvsl
#define _vel_vsll_vvsvl __builtin_ve_vl_vsll_vvsvl
#define _vel_vsll_vvvmvl __builtin_ve_vl_vsll_vvvmvl
#define _vel_vsll_vvsmvl __builtin_ve_vl_vsll_vvsmvl
#define _vel_pvsll_vvvl __builtin_ve_vl_pvsll_vvvl
#define _vel_pvsll_vvvvl __builtin_ve_vl_pvsll_vvvvl
#define _vel_pvsll_vvsl __builtin_ve_vl_pvsll_vvsl
#define _vel_pvsll_vvsvl __builtin_ve_vl_pvsll_vvsvl
#define _vel_pvsll_vvvMvl __builtin_ve_vl_pvsll_vvvMvl
#define _vel_pvsll_vvsMvl __builtin_ve_vl_pvsll_vvsMvl
#define _vel_vsrl_vvvl __builtin_ve_vl_vsrl_vvvl
#define _vel_vsrl_vvvvl __builtin_ve_vl_vsrl_vvvvl
#define _vel_vsrl_vvsl __builtin_ve_vl_vsrl_vvsl
#define _vel_vsrl_vvsvl __builtin_ve_vl_vsrl_vvsvl
#define _vel_vsrl_vvvmvl __builtin_ve_vl_vsrl_vvvmvl
#define _vel_vsrl_vvsmvl __builtin_ve_vl_vsrl_vvsmvl
#define _vel_pvsrl_vvvl __builtin_ve_vl_pvsrl_vvvl
#define _vel_pvsrl_vvvvl __builtin_ve_vl_pvsrl_vvvvl
#define _vel_pvsrl_vvsl __builtin_ve_vl_pvsrl_vvsl
#define _vel_pvsrl_vvsvl __builtin_ve_vl_pvsrl_vvsvl
#define _vel_pvsrl_vvvMvl __builtin_ve_vl_pvsrl_vvvMvl
#define _vel_pvsrl_vvsMvl __builtin_ve_vl_pvsrl_vvsMvl
#define _vel_vslawsx_vvvl __builtin_ve_vl_vslawsx_vvvl
#define _vel_vslawsx_vvvvl __builtin_ve_vl_vslawsx_vvvvl
#define _vel_vslawsx_vvsl __builtin_ve_vl_vslawsx_vvsl
#define _vel_vslawsx_vvsvl __builtin_ve_vl_vslawsx_vvsvl
#define _vel_vslawsx_vvvmvl __builtin_ve_vl_vslawsx_vvvmvl
#define _vel_vslawsx_vvsmvl __builtin_ve_vl_vslawsx_vvsmvl
#define _vel_vslawzx_vvvl __builtin_ve_vl_vslawzx_vvvl
#define _vel_vslawzx_vvvvl __builtin_ve_vl_vslawzx_vvvvl
#define _vel_vslawzx_vvsl __builtin_ve_vl_vslawzx_vvsl
#define _vel_vslawzx_vvsvl __builtin_ve_vl_vslawzx_vvsvl
#define _vel_vslawzx_vvvmvl __builtin_ve_vl_vslawzx_vvvmvl
#define _vel_vslawzx_vvsmvl __builtin_ve_vl_vslawzx_vvsmvl
#define _vel_pvsla_vvvl __builtin_ve_vl_pvsla_vvvl
#define _vel_pvsla_vvvvl __builtin_ve_vl_pvsla_vvvvl
#define _vel_pvsla_vvsl __builtin_ve_vl_pvsla_vvsl
#define _vel_pvsla_vvsvl __builtin_ve_vl_pvsla_vvsvl
#define _vel_pvsla_vvvMvl __builtin_ve_vl_pvsla_vvvMvl
#define _vel_pvsla_vvsMvl __builtin_ve_vl_pvsla_vvsMvl
#define _vel_vslal_vvvl __builtin_ve_vl_vslal_vvvl
#define _vel_vslal_vvvvl __builtin_ve_vl_vslal_vvvvl
#define _vel_vslal_vvsl __builtin_ve_vl_vslal_vvsl
#define _vel_vslal_vvsvl __builtin_ve_vl_vslal_vvsvl
#define _vel_vslal_vvvmvl __builtin_ve_vl_vslal_vvvmvl
#define _vel_vslal_vvsmvl __builtin_ve_vl_vslal_vvsmvl
#define _vel_vsrawsx_vvvl __builtin_ve_vl_vsrawsx_vvvl
#define _vel_vsrawsx_vvvvl __builtin_ve_vl_vsrawsx_vvvvl
#define _vel_vsrawsx_vvsl __builtin_ve_vl_vsrawsx_vvsl
#define _vel_vsrawsx_vvsvl __builtin_ve_vl_vsrawsx_vvsvl
#define _vel_vsrawsx_vvvmvl __builtin_ve_vl_vsrawsx_vvvmvl
#define _vel_vsrawsx_vvsmvl __builtin_ve_vl_vsrawsx_vvsmvl
#define _vel_vsrawzx_vvvl __builtin_ve_vl_vsrawzx_vvvl
#define _vel_vsrawzx_vvvvl __builtin_ve_vl_vsrawzx_vvvvl
#define _vel_vsrawzx_vvsl __builtin_ve_vl_vsrawzx_vvsl
#define _vel_vsrawzx_vvsvl __builtin_ve_vl_vsrawzx_vvsvl
#define _vel_vsrawzx_vvvmvl __builtin_ve_vl_vsrawzx_vvvmvl
#define _vel_vsrawzx_vvsmvl __builtin_ve_vl_vsrawzx_vvsmvl
#define _vel_pvsra_vvvl __builtin_ve_vl_pvsra_vvvl
#define _vel_pvsra_vvvvl __builtin_ve_vl_pvsra_vvvvl
#define _vel_pvsra_vvsl __builtin_ve_vl_pvsra_vvsl
#define _vel_pvsra_vvsvl __builtin_ve_vl_pvsra_vvsvl
#define _vel_pvsra_vvvMvl __builtin_ve_vl_pvsra_vvvMvl
#define _vel_pvsra_vvsMvl __builtin_ve_vl_pvsra_vvsMvl
#define _vel_vsral_vvvl __builtin_ve_vl_vsral_vvvl
#define _vel_vsral_vvvvl __builtin_ve_vl_vsral_vvvvl
#define _vel_vsral_vvsl __builtin_ve_vl_vsral_vvsl
#define _vel_vsral_vvsvl __builtin_ve_vl_vsral_vvsvl
#define _vel_vsral_vvvmvl __builtin_ve_vl_vsral_vvvmvl
#define _vel_vsral_vvsmvl __builtin_ve_vl_vsral_vvsmvl
#define _vel_vsfa_vvssl __builtin_ve_vl_vsfa_vvssl
#define _vel_vsfa_vvssvl __builtin_ve_vl_vsfa_vvssvl
#define _vel_vsfa_vvssmvl __builtin_ve_vl_vsfa_vvssmvl
#define _vel_vfaddd_vvvl __builtin_ve_vl_vfaddd_vvvl
#define _vel_vfaddd_vvvvl __builtin_ve_vl_vfaddd_vvvvl
#define _vel_vfaddd_vsvl __builtin_ve_vl_vfaddd_vsvl
#define _vel_vfaddd_vsvvl __builtin_ve_vl_vfaddd_vsvvl
#define _vel_vfaddd_vvvmvl __builtin_ve_vl_vfaddd_vvvmvl
#define _vel_vfaddd_vsvmvl __builtin_ve_vl_vfaddd_vsvmvl
#define _vel_vfadds_vvvl __builtin_ve_vl_vfadds_vvvl
#define _vel_vfadds_vvvvl __builtin_ve_vl_vfadds_vvvvl
#define _vel_vfadds_vsvl __builtin_ve_vl_vfadds_vsvl
#define _vel_vfadds_vsvvl __builtin_ve_vl_vfadds_vsvvl
#define _vel_vfadds_vvvmvl __builtin_ve_vl_vfadds_vvvmvl
#define _vel_vfadds_vsvmvl __builtin_ve_vl_vfadds_vsvmvl
#define _vel_pvfadd_vvvl __builtin_ve_vl_pvfadd_vvvl
#define _vel_pvfadd_vvvvl __builtin_ve_vl_pvfadd_vvvvl
#define _vel_pvfadd_vsvl __builtin_ve_vl_pvfadd_vsvl
#define _vel_pvfadd_vsvvl __builtin_ve_vl_pvfadd_vsvvl
#define _vel_pvfadd_vvvMvl __builtin_ve_vl_pvfadd_vvvMvl
#define _vel_pvfadd_vsvMvl __builtin_ve_vl_pvfadd_vsvMvl
#define _vel_vfsubd_vvvl __builtin_ve_vl_vfsubd_vvvl
#define _vel_vfsubd_vvvvl __builtin_ve_vl_vfsubd_vvvvl
#define _vel_vfsubd_vsvl __builtin_ve_vl_vfsubd_vsvl
#define _vel_vfsubd_vsvvl __builtin_ve_vl_vfsubd_vsvvl
#define _vel_vfsubd_vvvmvl __builtin_ve_vl_vfsubd_vvvmvl
#define _vel_vfsubd_vsvmvl __builtin_ve_vl_vfsubd_vsvmvl
#define _vel_vfsubs_vvvl __builtin_ve_vl_vfsubs_vvvl
#define _vel_vfsubs_vvvvl __builtin_ve_vl_vfsubs_vvvvl
#define _vel_vfsubs_vsvl __builtin_ve_vl_vfsubs_vsvl
#define _vel_vfsubs_vsvvl __builtin_ve_vl_vfsubs_vsvvl
#define _vel_vfsubs_vvvmvl __builtin_ve_vl_vfsubs_vvvmvl
#define _vel_vfsubs_vsvmvl __builtin_ve_vl_vfsubs_vsvmvl
#define _vel_pvfsub_vvvl __builtin_ve_vl_pvfsub_vvvl
#define _vel_pvfsub_vvvvl __builtin_ve_vl_pvfsub_vvvvl
#define _vel_pvfsub_vsvl __builtin_ve_vl_pvfsub_vsvl
#define _vel_pvfsub_vsvvl __builtin_ve_vl_pvfsub_vsvvl
#define _vel_pvfsub_vvvMvl __builtin_ve_vl_pvfsub_vvvMvl
#define _vel_pvfsub_vsvMvl __builtin_ve_vl_pvfsub_vsvMvl
#define _vel_vfmuld_vvvl __builtin_ve_vl_vfmuld_vvvl
#define _vel_vfmuld_vvvvl __builtin_ve_vl_vfmuld_vvvvl
#define _vel_vfmuld_vsvl __builtin_ve_vl_vfmuld_vsvl
#define _vel_vfmuld_vsvvl __builtin_ve_vl_vfmuld_vsvvl
#define _vel_vfmuld_vvvmvl __builtin_ve_vl_vfmuld_vvvmvl
#define _vel_vfmuld_vsvmvl __builtin_ve_vl_vfmuld_vsvmvl
#define _vel_vfmuls_vvvl __builtin_ve_vl_vfmuls_vvvl
#define _vel_vfmuls_vvvvl __builtin_ve_vl_vfmuls_vvvvl
#define _vel_vfmuls_vsvl __builtin_ve_vl_vfmuls_vsvl
#define _vel_vfmuls_vsvvl __builtin_ve_vl_vfmuls_vsvvl
#define _vel_vfmuls_vvvmvl __builtin_ve_vl_vfmuls_vvvmvl
#define _vel_vfmuls_vsvmvl __builtin_ve_vl_vfmuls_vsvmvl
#define _vel_pvfmul_vvvl __builtin_ve_vl_pvfmul_vvvl
#define _vel_pvfmul_vvvvl __builtin_ve_vl_pvfmul_vvvvl
#define _vel_pvfmul_vsvl __builtin_ve_vl_pvfmul_vsvl
#define _vel_pvfmul_vsvvl __builtin_ve_vl_pvfmul_vsvvl
#define _vel_pvfmul_vvvMvl __builtin_ve_vl_pvfmul_vvvMvl
#define _vel_pvfmul_vsvMvl __builtin_ve_vl_pvfmul_vsvMvl
#define _vel_vfdivd_vvvl __builtin_ve_vl_vfdivd_vvvl
#define _vel_vfdivd_vvvvl __builtin_ve_vl_vfdivd_vvvvl
#define _vel_vfdivd_vsvl __builtin_ve_vl_vfdivd_vsvl
#define _vel_vfdivd_vsvvl __builtin_ve_vl_vfdivd_vsvvl
#define _vel_vfdivd_vvvmvl __builtin_ve_vl_vfdivd_vvvmvl
#define _vel_vfdivd_vsvmvl __builtin_ve_vl_vfdivd_vsvmvl
#define _vel_vfdivs_vvvl __builtin_ve_vl_vfdivs_vvvl
#define _vel_vfdivs_vvvvl __builtin_ve_vl_vfdivs_vvvvl
#define _vel_vfdivs_vsvl __builtin_ve_vl_vfdivs_vsvl
#define _vel_vfdivs_vsvvl __builtin_ve_vl_vfdivs_vsvvl
#define _vel_vfdivs_vvvmvl __builtin_ve_vl_vfdivs_vvvmvl
#define _vel_vfdivs_vsvmvl __builtin_ve_vl_vfdivs_vsvmvl
#define _vel_vfsqrtd_vvl __builtin_ve_vl_vfsqrtd_vvl
#define _vel_vfsqrtd_vvvl __builtin_ve_vl_vfsqrtd_vvvl
#define _vel_vfsqrts_vvl __builtin_ve_vl_vfsqrts_vvl
#define _vel_vfsqrts_vvvl __builtin_ve_vl_vfsqrts_vvvl
#define _vel_vfcmpd_vvvl __builtin_ve_vl_vfcmpd_vvvl
#define _vel_vfcmpd_vvvvl __builtin_ve_vl_vfcmpd_vvvvl
#define _vel_vfcmpd_vsvl __builtin_ve_vl_vfcmpd_vsvl
#define _vel_vfcmpd_vsvvl __builtin_ve_vl_vfcmpd_vsvvl
#define _vel_vfcmpd_vvvmvl __builtin_ve_vl_vfcmpd_vvvmvl
#define _vel_vfcmpd_vsvmvl __builtin_ve_vl_vfcmpd_vsvmvl
#define _vel_vfcmps_vvvl __builtin_ve_vl_vfcmps_vvvl
#define _vel_vfcmps_vvvvl __builtin_ve_vl_vfcmps_vvvvl
#define _vel_vfcmps_vsvl __builtin_ve_vl_vfcmps_vsvl
#define _vel_vfcmps_vsvvl __builtin_ve_vl_vfcmps_vsvvl
#define _vel_vfcmps_vvvmvl __builtin_ve_vl_vfcmps_vvvmvl
#define _vel_vfcmps_vsvmvl __builtin_ve_vl_vfcmps_vsvmvl
#define _vel_pvfcmp_vvvl __builtin_ve_vl_pvfcmp_vvvl
#define _vel_pvfcmp_vvvvl __builtin_ve_vl_pvfcmp_vvvvl
#define _vel_pvfcmp_vsvl __builtin_ve_vl_pvfcmp_vsvl
#define _vel_pvfcmp_vsvvl __builtin_ve_vl_pvfcmp_vsvvl
#define _vel_pvfcmp_vvvMvl __builtin_ve_vl_pvfcmp_vvvMvl
#define _vel_pvfcmp_vsvMvl __builtin_ve_vl_pvfcmp_vsvMvl
#define _vel_vfmaxd_vvvl __builtin_ve_vl_vfmaxd_vvvl
#define _vel_vfmaxd_vvvvl __builtin_ve_vl_vfmaxd_vvvvl
#define _vel_vfmaxd_vsvl __builtin_ve_vl_vfmaxd_vsvl
#define _vel_vfmaxd_vsvvl __builtin_ve_vl_vfmaxd_vsvvl
#define _vel_vfmaxd_vvvmvl __builtin_ve_vl_vfmaxd_vvvmvl
#define _vel_vfmaxd_vsvmvl __builtin_ve_vl_vfmaxd_vsvmvl
#define _vel_vfmaxs_vvvl __builtin_ve_vl_vfmaxs_vvvl
#define _vel_vfmaxs_vvvvl __builtin_ve_vl_vfmaxs_vvvvl
#define _vel_vfmaxs_vsvl __builtin_ve_vl_vfmaxs_vsvl
#define _vel_vfmaxs_vsvvl __builtin_ve_vl_vfmaxs_vsvvl
#define _vel_vfmaxs_vvvmvl __builtin_ve_vl_vfmaxs_vvvmvl
#define _vel_vfmaxs_vsvmvl __builtin_ve_vl_vfmaxs_vsvmvl
#define _vel_pvfmax_vvvl __builtin_ve_vl_pvfmax_vvvl
#define _vel_pvfmax_vvvvl __builtin_ve_vl_pvfmax_vvvvl
#define _vel_pvfmax_vsvl __builtin_ve_vl_pvfmax_vsvl
#define _vel_pvfmax_vsvvl __builtin_ve_vl_pvfmax_vsvvl
#define _vel_pvfmax_vvvMvl __builtin_ve_vl_pvfmax_vvvMvl
#define _vel_pvfmax_vsvMvl __builtin_ve_vl_pvfmax_vsvMvl
#define _vel_vfmind_vvvl __builtin_ve_vl_vfmind_vvvl
#define _vel_vfmind_vvvvl __builtin_ve_vl_vfmind_vvvvl
#define _vel_vfmind_vsvl __builtin_ve_vl_vfmind_vsvl
#define _vel_vfmind_vsvvl __builtin_ve_vl_vfmind_vsvvl
#define _vel_vfmind_vvvmvl __builtin_ve_vl_vfmind_vvvmvl
#define _vel_vfmind_vsvmvl __builtin_ve_vl_vfmind_vsvmvl
#define _vel_vfmins_vvvl __builtin_ve_vl_vfmins_vvvl
#define _vel_vfmins_vvvvl __builtin_ve_vl_vfmins_vvvvl
#define _vel_vfmins_vsvl __builtin_ve_vl_vfmins_vsvl
#define _vel_vfmins_vsvvl __builtin_ve_vl_vfmins_vsvvl
#define _vel_vfmins_vvvmvl __builtin_ve_vl_vfmins_vvvmvl
#define _vel_vfmins_vsvmvl __builtin_ve_vl_vfmins_vsvmvl
#define _vel_pvfmin_vvvl __builtin_ve_vl_pvfmin_vvvl
#define _vel_pvfmin_vvvvl __builtin_ve_vl_pvfmin_vvvvl
#define _vel_pvfmin_vsvl __builtin_ve_vl_pvfmin_vsvl
#define _vel_pvfmin_vsvvl __builtin_ve_vl_pvfmin_vsvvl
#define _vel_pvfmin_vvvMvl __builtin_ve_vl_pvfmin_vvvMvl
#define _vel_pvfmin_vsvMvl __builtin_ve_vl_pvfmin_vsvMvl
#define _vel_vfmadd_vvvvl __builtin_ve_vl_vfmadd_vvvvl
#define _vel_vfmadd_vvvvvl __builtin_ve_vl_vfmadd_vvvvvl
#define _vel_vfmadd_vsvvl __builtin_ve_vl_vfmadd_vsvvl
#define _vel_vfmadd_vsvvvl __builtin_ve_vl_vfmadd_vsvvvl
#define _vel_vfmadd_vvsvl __builtin_ve_vl_vfmadd_vvsvl
#define _vel_vfmadd_vvsvvl __builtin_ve_vl_vfmadd_vvsvvl
#define _vel_vfmadd_vvvvmvl __builtin_ve_vl_vfmadd_vvvvmvl
#define _vel_vfmadd_vsvvmvl __builtin_ve_vl_vfmadd_vsvvmvl
#define _vel_vfmadd_vvsvmvl __builtin_ve_vl_vfmadd_vvsvmvl
#define _vel_vfmads_vvvvl __builtin_ve_vl_vfmads_vvvvl
#define _vel_vfmads_vvvvvl __builtin_ve_vl_vfmads_vvvvvl
#define _vel_vfmads_vsvvl __builtin_ve_vl_vfmads_vsvvl
#define _vel_vfmads_vsvvvl __builtin_ve_vl_vfmads_vsvvvl
#define _vel_vfmads_vvsvl __builtin_ve_vl_vfmads_vvsvl
#define _vel_vfmads_vvsvvl __builtin_ve_vl_vfmads_vvsvvl
#define _vel_vfmads_vvvvmvl __builtin_ve_vl_vfmads_vvvvmvl
#define _vel_vfmads_vsvvmvl __builtin_ve_vl_vfmads_vsvvmvl
#define _vel_vfmads_vvsvmvl __builtin_ve_vl_vfmads_vvsvmvl
#define _vel_pvfmad_vvvvl __builtin_ve_vl_pvfmad_vvvvl
#define _vel_pvfmad_vvvvvl __builtin_ve_vl_pvfmad_vvvvvl
#define _vel_pvfmad_vsvvl __builtin_ve_vl_pvfmad_vsvvl
#define _vel_pvfmad_vsvvvl __builtin_ve_vl_pvfmad_vsvvvl
#define _vel_pvfmad_vvsvl __builtin_ve_vl_pvfmad_vvsvl
#define _vel_pvfmad_vvsvvl __builtin_ve_vl_pvfmad_vvsvvl
#define _vel_pvfmad_vvvvMvl __builtin_ve_vl_pvfmad_vvvvMvl
#define _vel_pvfmad_vsvvMvl __builtin_ve_vl_pvfmad_vsvvMvl
#define _vel_pvfmad_vvsvMvl __builtin_ve_vl_pvfmad_vvsvMvl
#define _vel_vfmsbd_vvvvl __builtin_ve_vl_vfmsbd_vvvvl
#define _vel_vfmsbd_vvvvvl __builtin_ve_vl_vfmsbd_vvvvvl
#define _vel_vfmsbd_vsvvl __builtin_ve_vl_vfmsbd_vsvvl
#define _vel_vfmsbd_vsvvvl __builtin_ve_vl_vfmsbd_vsvvvl
#define _vel_vfmsbd_vvsvl __builtin_ve_vl_vfmsbd_vvsvl
#define _vel_vfmsbd_vvsvvl __builtin_ve_vl_vfmsbd_vvsvvl
#define _vel_vfmsbd_vvvvmvl __builtin_ve_vl_vfmsbd_vvvvmvl
#define _vel_vfmsbd_vsvvmvl __builtin_ve_vl_vfmsbd_vsvvmvl
#define _vel_vfmsbd_vvsvmvl __builtin_ve_vl_vfmsbd_vvsvmvl
#define _vel_vfmsbs_vvvvl __builtin_ve_vl_vfmsbs_vvvvl
#define _vel_vfmsbs_vvvvvl __builtin_ve_vl_vfmsbs_vvvvvl
#define _vel_vfmsbs_vsvvl __builtin_ve_vl_vfmsbs_vsvvl
#define _vel_vfmsbs_vsvvvl __builtin_ve_vl_vfmsbs_vsvvvl
#define _vel_vfmsbs_vvsvl __builtin_ve_vl_vfmsbs_vvsvl
#define _vel_vfmsbs_vvsvvl __builtin_ve_vl_vfmsbs_vvsvvl
#define _vel_vfmsbs_vvvvmvl __builtin_ve_vl_vfmsbs_vvvvmvl
#define _vel_vfmsbs_vsvvmvl __builtin_ve_vl_vfmsbs_vsvvmvl
#define _vel_vfmsbs_vvsvmvl __builtin_ve_vl_vfmsbs_vvsvmvl
#define _vel_pvfmsb_vvvvl __builtin_ve_vl_pvfmsb_vvvvl
#define _vel_pvfmsb_vvvvvl __builtin_ve_vl_pvfmsb_vvvvvl
#define _vel_pvfmsb_vsvvl __builtin_ve_vl_pvfmsb_vsvvl
#define _vel_pvfmsb_vsvvvl __builtin_ve_vl_pvfmsb_vsvvvl
#define _vel_pvfmsb_vvsvl __builtin_ve_vl_pvfmsb_vvsvl
#define _vel_pvfmsb_vvsvvl __builtin_ve_vl_pvfmsb_vvsvvl
#define _vel_pvfmsb_vvvvMvl __builtin_ve_vl_pvfmsb_vvvvMvl
#define _vel_pvfmsb_vsvvMvl __builtin_ve_vl_pvfmsb_vsvvMvl
#define _vel_pvfmsb_vvsvMvl __builtin_ve_vl_pvfmsb_vvsvMvl
#define _vel_vfnmadd_vvvvl __builtin_ve_vl_vfnmadd_vvvvl
#define _vel_vfnmadd_vvvvvl __builtin_ve_vl_vfnmadd_vvvvvl
#define _vel_vfnmadd_vsvvl __builtin_ve_vl_vfnmadd_vsvvl
#define _vel_vfnmadd_vsvvvl __builtin_ve_vl_vfnmadd_vsvvvl
#define _vel_vfnmadd_vvsvl __builtin_ve_vl_vfnmadd_vvsvl
#define _vel_vfnmadd_vvsvvl __builtin_ve_vl_vfnmadd_vvsvvl
#define _vel_vfnmadd_vvvvmvl __builtin_ve_vl_vfnmadd_vvvvmvl
#define _vel_vfnmadd_vsvvmvl __builtin_ve_vl_vfnmadd_vsvvmvl
#define _vel_vfnmadd_vvsvmvl __builtin_ve_vl_vfnmadd_vvsvmvl
#define _vel_vfnmads_vvvvl __builtin_ve_vl_vfnmads_vvvvl
#define _vel_vfnmads_vvvvvl __builtin_ve_vl_vfnmads_vvvvvl
#define _vel_vfnmads_vsvvl __builtin_ve_vl_vfnmads_vsvvl
#define _vel_vfnmads_vsvvvl __builtin_ve_vl_vfnmads_vsvvvl
#define _vel_vfnmads_vvsvl __builtin_ve_vl_vfnmads_vvsvl
#define _vel_vfnmads_vvsvvl __builtin_ve_vl_vfnmads_vvsvvl
#define _vel_vfnmads_vvvvmvl __builtin_ve_vl_vfnmads_vvvvmvl
#define _vel_vfnmads_vsvvmvl __builtin_ve_vl_vfnmads_vsvvmvl
#define _vel_vfnmads_vvsvmvl __builtin_ve_vl_vfnmads_vvsvmvl
#define _vel_pvfnmad_vvvvl __builtin_ve_vl_pvfnmad_vvvvl
#define _vel_pvfnmad_vvvvvl __builtin_ve_vl_pvfnmad_vvvvvl
#define _vel_pvfnmad_vsvvl __builtin_ve_vl_pvfnmad_vsvvl
#define _vel_pvfnmad_vsvvvl __builtin_ve_vl_pvfnmad_vsvvvl
#define _vel_pvfnmad_vvsvl __builtin_ve_vl_pvfnmad_vvsvl
#define _vel_pvfnmad_vvsvvl __builtin_ve_vl_pvfnmad_vvsvvl
#define _vel_pvfnmad_vvvvMvl __builtin_ve_vl_pvfnmad_vvvvMvl
#define _vel_pvfnmad_vsvvMvl __builtin_ve_vl_pvfnmad_vsvvMvl
#define _vel_pvfnmad_vvsvMvl __builtin_ve_vl_pvfnmad_vvsvMvl
#define _vel_vfnmsbd_vvvvl __builtin_ve_vl_vfnmsbd_vvvvl
#define _vel_vfnmsbd_vvvvvl __builtin_ve_vl_vfnmsbd_vvvvvl
#define _vel_vfnmsbd_vsvvl __builtin_ve_vl_vfnmsbd_vsvvl
#define _vel_vfnmsbd_vsvvvl __builtin_ve_vl_vfnmsbd_vsvvvl
#define _vel_vfnmsbd_vvsvl __builtin_ve_vl_vfnmsbd_vvsvl
#define _vel_vfnmsbd_vvsvvl __builtin_ve_vl_vfnmsbd_vvsvvl
#define _vel_vfnmsbd_vvvvmvl __builtin_ve_vl_vfnmsbd_vvvvmvl
#define _vel_vfnmsbd_vsvvmvl __builtin_ve_vl_vfnmsbd_vsvvmvl
#define _vel_vfnmsbd_vvsvmvl __builtin_ve_vl_vfnmsbd_vvsvmvl
#define _vel_vfnmsbs_vvvvl __builtin_ve_vl_vfnmsbs_vvvvl
#define _vel_vfnmsbs_vvvvvl __builtin_ve_vl_vfnmsbs_vvvvvl
#define _vel_vfnmsbs_vsvvl __builtin_ve_vl_vfnmsbs_vsvvl
#define _vel_vfnmsbs_vsvvvl __builtin_ve_vl_vfnmsbs_vsvvvl
#define _vel_vfnmsbs_vvsvl __builtin_ve_vl_vfnmsbs_vvsvl
#define _vel_vfnmsbs_vvsvvl __builtin_ve_vl_vfnmsbs_vvsvvl
#define _vel_vfnmsbs_vvvvmvl __builtin_ve_vl_vfnmsbs_vvvvmvl
#define _vel_vfnmsbs_vsvvmvl __builtin_ve_vl_vfnmsbs_vsvvmvl
#define _vel_vfnmsbs_vvsvmvl __builtin_ve_vl_vfnmsbs_vvsvmvl
#define _vel_pvfnmsb_vvvvl __builtin_ve_vl_pvfnmsb_vvvvl
#define _vel_pvfnmsb_vvvvvl __builtin_ve_vl_pvfnmsb_vvvvvl
#define _vel_pvfnmsb_vsvvl __builtin_ve_vl_pvfnmsb_vsvvl
#define _vel_pvfnmsb_vsvvvl __builtin_ve_vl_pvfnmsb_vsvvvl
#define _vel_pvfnmsb_vvsvl __builtin_ve_vl_pvfnmsb_vvsvl
#define _vel_pvfnmsb_vvsvvl __builtin_ve_vl_pvfnmsb_vvsvvl
#define _vel_pvfnmsb_vvvvMvl __builtin_ve_vl_pvfnmsb_vvvvMvl
#define _vel_pvfnmsb_vsvvMvl __builtin_ve_vl_pvfnmsb_vsvvMvl
#define _vel_pvfnmsb_vvsvMvl __builtin_ve_vl_pvfnmsb_vvsvMvl
#define _vel_vrcpd_vvl __builtin_ve_vl_vrcpd_vvl
#define _vel_vrcpd_vvvl __builtin_ve_vl_vrcpd_vvvl
#define _vel_vrcps_vvl __builtin_ve_vl_vrcps_vvl
#define _vel_vrcps_vvvl __builtin_ve_vl_vrcps_vvvl
#define _vel_pvrcp_vvl __builtin_ve_vl_pvrcp_vvl
#define _vel_pvrcp_vvvl __builtin_ve_vl_pvrcp_vvvl
#define _vel_vrsqrtd_vvl __builtin_ve_vl_vrsqrtd_vvl
#define _vel_vrsqrtd_vvvl __builtin_ve_vl_vrsqrtd_vvvl
#define _vel_vrsqrts_vvl __builtin_ve_vl_vrsqrts_vvl
#define _vel_vrsqrts_vvvl __builtin_ve_vl_vrsqrts_vvvl
#define _vel_pvrsqrt_vvl __builtin_ve_vl_pvrsqrt_vvl
#define _vel_pvrsqrt_vvvl __builtin_ve_vl_pvrsqrt_vvvl
#define _vel_vrsqrtdnex_vvl __builtin_ve_vl_vrsqrtdnex_vvl
#define _vel_vrsqrtdnex_vvvl __builtin_ve_vl_vrsqrtdnex_vvvl
#define _vel_vrsqrtsnex_vvl __builtin_ve_vl_vrsqrtsnex_vvl
#define _vel_vrsqrtsnex_vvvl __builtin_ve_vl_vrsqrtsnex_vvvl
#define _vel_pvrsqrtnex_vvl __builtin_ve_vl_pvrsqrtnex_vvl
#define _vel_pvrsqrtnex_vvvl __builtin_ve_vl_pvrsqrtnex_vvvl
#define _vel_vcvtwdsx_vvl __builtin_ve_vl_vcvtwdsx_vvl
#define _vel_vcvtwdsx_vvvl __builtin_ve_vl_vcvtwdsx_vvvl
#define _vel_vcvtwdsx_vvmvl __builtin_ve_vl_vcvtwdsx_vvmvl
#define _vel_vcvtwdsxrz_vvl __builtin_ve_vl_vcvtwdsxrz_vvl
#define _vel_vcvtwdsxrz_vvvl __builtin_ve_vl_vcvtwdsxrz_vvvl
#define _vel_vcvtwdsxrz_vvmvl __builtin_ve_vl_vcvtwdsxrz_vvmvl
#define _vel_vcvtwdzx_vvl __builtin_ve_vl_vcvtwdzx_vvl
#define _vel_vcvtwdzx_vvvl __builtin_ve_vl_vcvtwdzx_vvvl
#define _vel_vcvtwdzx_vvmvl __builtin_ve_vl_vcvtwdzx_vvmvl
#define _vel_vcvtwdzxrz_vvl __builtin_ve_vl_vcvtwdzxrz_vvl
#define _vel_vcvtwdzxrz_vvvl __builtin_ve_vl_vcvtwdzxrz_vvvl
#define _vel_vcvtwdzxrz_vvmvl __builtin_ve_vl_vcvtwdzxrz_vvmvl
#define _vel_vcvtwssx_vvl __builtin_ve_vl_vcvtwssx_vvl
#define _vel_vcvtwssx_vvvl __builtin_ve_vl_vcvtwssx_vvvl
#define _vel_vcvtwssx_vvmvl __builtin_ve_vl_vcvtwssx_vvmvl
#define _vel_vcvtwssxrz_vvl __builtin_ve_vl_vcvtwssxrz_vvl
#define _vel_vcvtwssxrz_vvvl __builtin_ve_vl_vcvtwssxrz_vvvl
#define _vel_vcvtwssxrz_vvmvl __builtin_ve_vl_vcvtwssxrz_vvmvl
#define _vel_vcvtwszx_vvl __builtin_ve_vl_vcvtwszx_vvl
#define _vel_vcvtwszx_vvvl __builtin_ve_vl_vcvtwszx_vvvl
#define _vel_vcvtwszx_vvmvl __builtin_ve_vl_vcvtwszx_vvmvl
#define _vel_vcvtwszxrz_vvl __builtin_ve_vl_vcvtwszxrz_vvl
#define _vel_vcvtwszxrz_vvvl __builtin_ve_vl_vcvtwszxrz_vvvl
#define _vel_vcvtwszxrz_vvmvl __builtin_ve_vl_vcvtwszxrz_vvmvl
#define _vel_pvcvtws_vvl __builtin_ve_vl_pvcvtws_vvl
#define _vel_pvcvtws_vvvl __builtin_ve_vl_pvcvtws_vvvl
#define _vel_pvcvtws_vvMvl __builtin_ve_vl_pvcvtws_vvMvl
#define _vel_pvcvtwsrz_vvl __builtin_ve_vl_pvcvtwsrz_vvl
#define _vel_pvcvtwsrz_vvvl __builtin_ve_vl_pvcvtwsrz_vvvl
#define _vel_pvcvtwsrz_vvMvl __builtin_ve_vl_pvcvtwsrz_vvMvl
#define _vel_vcvtld_vvl __builtin_ve_vl_vcvtld_vvl
#define _vel_vcvtld_vvvl __builtin_ve_vl_vcvtld_vvvl
#define _vel_vcvtld_vvmvl __builtin_ve_vl_vcvtld_vvmvl
#define _vel_vcvtldrz_vvl __builtin_ve_vl_vcvtldrz_vvl
#define _vel_vcvtldrz_vvvl __builtin_ve_vl_vcvtldrz_vvvl
#define _vel_vcvtldrz_vvmvl __builtin_ve_vl_vcvtldrz_vvmvl
#define _vel_vcvtdw_vvl __builtin_ve_vl_vcvtdw_vvl
#define _vel_vcvtdw_vvvl __builtin_ve_vl_vcvtdw_vvvl
#define _vel_vcvtsw_vvl __builtin_ve_vl_vcvtsw_vvl
#define _vel_vcvtsw_vvvl __builtin_ve_vl_vcvtsw_vvvl
#define _vel_pvcvtsw_vvl __builtin_ve_vl_pvcvtsw_vvl
#define _vel_pvcvtsw_vvvl __builtin_ve_vl_pvcvtsw_vvvl
#define _vel_vcvtdl_vvl __builtin_ve_vl_vcvtdl_vvl
#define _vel_vcvtdl_vvvl __builtin_ve_vl_vcvtdl_vvvl
#define _vel_vcvtds_vvl __builtin_ve_vl_vcvtds_vvl
#define _vel_vcvtds_vvvl __builtin_ve_vl_vcvtds_vvvl
#define _vel_vcvtsd_vvl __builtin_ve_vl_vcvtsd_vvl
#define _vel_vcvtsd_vvvl __builtin_ve_vl_vcvtsd_vvvl
#define _vel_vmrg_vvvml __builtin_ve_vl_vmrg_vvvml
#define _vel_vmrg_vvvmvl __builtin_ve_vl_vmrg_vvvmvl
#define _vel_vmrg_vsvml __builtin_ve_vl_vmrg_vsvml
#define _vel_vmrg_vsvmvl __builtin_ve_vl_vmrg_vsvmvl
#define _vel_vmrgw_vvvMl __builtin_ve_vl_vmrgw_vvvMl
#define _vel_vmrgw_vvvMvl __builtin_ve_vl_vmrgw_vvvMvl
#define _vel_vmrgw_vsvMl __builtin_ve_vl_vmrgw_vsvMl
#define _vel_vmrgw_vsvMvl __builtin_ve_vl_vmrgw_vsvMvl
#define _vel_vshf_vvvsl __builtin_ve_vl_vshf_vvvsl
#define _vel_vshf_vvvsvl __builtin_ve_vl_vshf_vvvsvl
#define _vel_vcp_vvmvl __builtin_ve_vl_vcp_vvmvl
#define _vel_vex_vvmvl __builtin_ve_vl_vex_vvmvl
#define _vel_vfmklat_ml __builtin_ve_vl_vfmklat_ml
#define _vel_vfmklaf_ml __builtin_ve_vl_vfmklaf_ml
#define _vel_pvfmkat_Ml __builtin_ve_vl_pvfmkat_Ml
#define _vel_pvfmkaf_Ml __builtin_ve_vl_pvfmkaf_Ml
#define _vel_vfmklgt_mvl __builtin_ve_vl_vfmklgt_mvl
#define _vel_vfmklgt_mvml __builtin_ve_vl_vfmklgt_mvml
#define _vel_vfmkllt_mvl __builtin_ve_vl_vfmkllt_mvl
#define _vel_vfmkllt_mvml __builtin_ve_vl_vfmkllt_mvml
#define _vel_vfmklne_mvl __builtin_ve_vl_vfmklne_mvl
#define _vel_vfmklne_mvml __builtin_ve_vl_vfmklne_mvml
#define _vel_vfmkleq_mvl __builtin_ve_vl_vfmkleq_mvl
#define _vel_vfmkleq_mvml __builtin_ve_vl_vfmkleq_mvml
#define _vel_vfmklge_mvl __builtin_ve_vl_vfmklge_mvl
#define _vel_vfmklge_mvml __builtin_ve_vl_vfmklge_mvml
#define _vel_vfmklle_mvl __builtin_ve_vl_vfmklle_mvl
#define _vel_vfmklle_mvml __builtin_ve_vl_vfmklle_mvml
#define _vel_vfmklnum_mvl __builtin_ve_vl_vfmklnum_mvl
#define _vel_vfmklnum_mvml __builtin_ve_vl_vfmklnum_mvml
#define _vel_vfmklnan_mvl __builtin_ve_vl_vfmklnan_mvl
#define _vel_vfmklnan_mvml __builtin_ve_vl_vfmklnan_mvml
#define _vel_vfmklgtnan_mvl __builtin_ve_vl_vfmklgtnan_mvl
#define _vel_vfmklgtnan_mvml __builtin_ve_vl_vfmklgtnan_mvml
#define _vel_vfmklltnan_mvl __builtin_ve_vl_vfmklltnan_mvl
#define _vel_vfmklltnan_mvml __builtin_ve_vl_vfmklltnan_mvml
#define _vel_vfmklnenan_mvl __builtin_ve_vl_vfmklnenan_mvl
#define _vel_vfmklnenan_mvml __builtin_ve_vl_vfmklnenan_mvml
#define _vel_vfmkleqnan_mvl __builtin_ve_vl_vfmkleqnan_mvl
#define _vel_vfmkleqnan_mvml __builtin_ve_vl_vfmkleqnan_mvml
#define _vel_vfmklgenan_mvl __builtin_ve_vl_vfmklgenan_mvl
#define _vel_vfmklgenan_mvml __builtin_ve_vl_vfmklgenan_mvml
#define _vel_vfmkllenan_mvl __builtin_ve_vl_vfmkllenan_mvl
#define _vel_vfmkllenan_mvml __builtin_ve_vl_vfmkllenan_mvml
#define _vel_vfmkwgt_mvl __builtin_ve_vl_vfmkwgt_mvl
#define _vel_vfmkwgt_mvml __builtin_ve_vl_vfmkwgt_mvml
#define _vel_vfmkwlt_mvl __builtin_ve_vl_vfmkwlt_mvl
#define _vel_vfmkwlt_mvml __builtin_ve_vl_vfmkwlt_mvml
#define _vel_vfmkwne_mvl __builtin_ve_vl_vfmkwne_mvl
#define _vel_vfmkwne_mvml __builtin_ve_vl_vfmkwne_mvml
#define _vel_vfmkweq_mvl __builtin_ve_vl_vfmkweq_mvl
#define _vel_vfmkweq_mvml __builtin_ve_vl_vfmkweq_mvml
#define _vel_vfmkwge_mvl __builtin_ve_vl_vfmkwge_mvl
#define _vel_vfmkwge_mvml __builtin_ve_vl_vfmkwge_mvml
#define _vel_vfmkwle_mvl __builtin_ve_vl_vfmkwle_mvl
#define _vel_vfmkwle_mvml __builtin_ve_vl_vfmkwle_mvml
#define _vel_vfmkwnum_mvl __builtin_ve_vl_vfmkwnum_mvl
#define _vel_vfmkwnum_mvml __builtin_ve_vl_vfmkwnum_mvml
#define _vel_vfmkwnan_mvl __builtin_ve_vl_vfmkwnan_mvl
#define _vel_vfmkwnan_mvml __builtin_ve_vl_vfmkwnan_mvml
#define _vel_vfmkwgtnan_mvl __builtin_ve_vl_vfmkwgtnan_mvl
#define _vel_vfmkwgtnan_mvml __builtin_ve_vl_vfmkwgtnan_mvml
#define _vel_vfmkwltnan_mvl __builtin_ve_vl_vfmkwltnan_mvl
#define _vel_vfmkwltnan_mvml __builtin_ve_vl_vfmkwltnan_mvml
#define _vel_vfmkwnenan_mvl __builtin_ve_vl_vfmkwnenan_mvl
#define _vel_vfmkwnenan_mvml __builtin_ve_vl_vfmkwnenan_mvml
#define _vel_vfmkweqnan_mvl __builtin_ve_vl_vfmkweqnan_mvl
#define _vel_vfmkweqnan_mvml __builtin_ve_vl_vfmkweqnan_mvml
#define _vel_vfmkwgenan_mvl __builtin_ve_vl_vfmkwgenan_mvl
#define _vel_vfmkwgenan_mvml __builtin_ve_vl_vfmkwgenan_mvml
#define _vel_vfmkwlenan_mvl __builtin_ve_vl_vfmkwlenan_mvl
#define _vel_vfmkwlenan_mvml __builtin_ve_vl_vfmkwlenan_mvml
#define _vel_pvfmkwlogt_mvl __builtin_ve_vl_pvfmkwlogt_mvl
#define _vel_pvfmkwupgt_mvl __builtin_ve_vl_pvfmkwupgt_mvl
#define _vel_pvfmkwlogt_mvml __builtin_ve_vl_pvfmkwlogt_mvml
#define _vel_pvfmkwupgt_mvml __builtin_ve_vl_pvfmkwupgt_mvml
#define _vel_pvfmkwlolt_mvl __builtin_ve_vl_pvfmkwlolt_mvl
#define _vel_pvfmkwuplt_mvl __builtin_ve_vl_pvfmkwuplt_mvl
#define _vel_pvfmkwlolt_mvml __builtin_ve_vl_pvfmkwlolt_mvml
#define _vel_pvfmkwuplt_mvml __builtin_ve_vl_pvfmkwuplt_mvml
#define _vel_pvfmkwlone_mvl __builtin_ve_vl_pvfmkwlone_mvl
#define _vel_pvfmkwupne_mvl __builtin_ve_vl_pvfmkwupne_mvl
#define _vel_pvfmkwlone_mvml __builtin_ve_vl_pvfmkwlone_mvml
#define _vel_pvfmkwupne_mvml __builtin_ve_vl_pvfmkwupne_mvml
#define _vel_pvfmkwloeq_mvl __builtin_ve_vl_pvfmkwloeq_mvl
#define _vel_pvfmkwupeq_mvl __builtin_ve_vl_pvfmkwupeq_mvl
#define _vel_pvfmkwloeq_mvml __builtin_ve_vl_pvfmkwloeq_mvml
#define _vel_pvfmkwupeq_mvml __builtin_ve_vl_pvfmkwupeq_mvml
#define _vel_pvfmkwloge_mvl __builtin_ve_vl_pvfmkwloge_mvl
#define _vel_pvfmkwupge_mvl __builtin_ve_vl_pvfmkwupge_mvl
#define _vel_pvfmkwloge_mvml __builtin_ve_vl_pvfmkwloge_mvml
#define _vel_pvfmkwupge_mvml __builtin_ve_vl_pvfmkwupge_mvml
#define _vel_pvfmkwlole_mvl __builtin_ve_vl_pvfmkwlole_mvl
#define _vel_pvfmkwuple_mvl __builtin_ve_vl_pvfmkwuple_mvl
#define _vel_pvfmkwlole_mvml __builtin_ve_vl_pvfmkwlole_mvml
#define _vel_pvfmkwuple_mvml __builtin_ve_vl_pvfmkwuple_mvml
#define _vel_pvfmkwlonum_mvl __builtin_ve_vl_pvfmkwlonum_mvl
#define _vel_pvfmkwupnum_mvl __builtin_ve_vl_pvfmkwupnum_mvl
#define _vel_pvfmkwlonum_mvml __builtin_ve_vl_pvfmkwlonum_mvml
#define _vel_pvfmkwupnum_mvml __builtin_ve_vl_pvfmkwupnum_mvml
#define _vel_pvfmkwlonan_mvl __builtin_ve_vl_pvfmkwlonan_mvl
#define _vel_pvfmkwupnan_mvl __builtin_ve_vl_pvfmkwupnan_mvl
#define _vel_pvfmkwlonan_mvml __builtin_ve_vl_pvfmkwlonan_mvml
#define _vel_pvfmkwupnan_mvml __builtin_ve_vl_pvfmkwupnan_mvml
#define _vel_pvfmkwlogtnan_mvl __builtin_ve_vl_pvfmkwlogtnan_mvl
#define _vel_pvfmkwupgtnan_mvl __builtin_ve_vl_pvfmkwupgtnan_mvl
#define _vel_pvfmkwlogtnan_mvml __builtin_ve_vl_pvfmkwlogtnan_mvml
#define _vel_pvfmkwupgtnan_mvml __builtin_ve_vl_pvfmkwupgtnan_mvml
#define _vel_pvfmkwloltnan_mvl __builtin_ve_vl_pvfmkwloltnan_mvl
#define _vel_pvfmkwupltnan_mvl __builtin_ve_vl_pvfmkwupltnan_mvl
#define _vel_pvfmkwloltnan_mvml __builtin_ve_vl_pvfmkwloltnan_mvml
#define _vel_pvfmkwupltnan_mvml __builtin_ve_vl_pvfmkwupltnan_mvml
#define _vel_pvfmkwlonenan_mvl __builtin_ve_vl_pvfmkwlonenan_mvl
#define _vel_pvfmkwupnenan_mvl __builtin_ve_vl_pvfmkwupnenan_mvl
#define _vel_pvfmkwlonenan_mvml __builtin_ve_vl_pvfmkwlonenan_mvml
#define _vel_pvfmkwupnenan_mvml __builtin_ve_vl_pvfmkwupnenan_mvml
#define _vel_pvfmkwloeqnan_mvl __builtin_ve_vl_pvfmkwloeqnan_mvl
#define _vel_pvfmkwupeqnan_mvl __builtin_ve_vl_pvfmkwupeqnan_mvl
#define _vel_pvfmkwloeqnan_mvml __builtin_ve_vl_pvfmkwloeqnan_mvml
#define _vel_pvfmkwupeqnan_mvml __builtin_ve_vl_pvfmkwupeqnan_mvml
#define _vel_pvfmkwlogenan_mvl __builtin_ve_vl_pvfmkwlogenan_mvl
#define _vel_pvfmkwupgenan_mvl __builtin_ve_vl_pvfmkwupgenan_mvl
#define _vel_pvfmkwlogenan_mvml __builtin_ve_vl_pvfmkwlogenan_mvml
#define _vel_pvfmkwupgenan_mvml __builtin_ve_vl_pvfmkwupgenan_mvml
#define _vel_pvfmkwlolenan_mvl __builtin_ve_vl_pvfmkwlolenan_mvl
#define _vel_pvfmkwuplenan_mvl __builtin_ve_vl_pvfmkwuplenan_mvl
#define _vel_pvfmkwlolenan_mvml __builtin_ve_vl_pvfmkwlolenan_mvml
#define _vel_pvfmkwuplenan_mvml __builtin_ve_vl_pvfmkwuplenan_mvml
#define _vel_pvfmkwgt_Mvl __builtin_ve_vl_pvfmkwgt_Mvl
#define _vel_pvfmkwgt_MvMl __builtin_ve_vl_pvfmkwgt_MvMl
#define _vel_pvfmkwlt_Mvl __builtin_ve_vl_pvfmkwlt_Mvl
#define _vel_pvfmkwlt_MvMl __builtin_ve_vl_pvfmkwlt_MvMl
#define _vel_pvfmkwne_Mvl __builtin_ve_vl_pvfmkwne_Mvl
#define _vel_pvfmkwne_MvMl __builtin_ve_vl_pvfmkwne_MvMl
#define _vel_pvfmkweq_Mvl __builtin_ve_vl_pvfmkweq_Mvl
#define _vel_pvfmkweq_MvMl __builtin_ve_vl_pvfmkweq_MvMl
#define _vel_pvfmkwge_Mvl __builtin_ve_vl_pvfmkwge_Mvl
#define _vel_pvfmkwge_MvMl __builtin_ve_vl_pvfmkwge_MvMl
#define _vel_pvfmkwle_Mvl __builtin_ve_vl_pvfmkwle_Mvl
#define _vel_pvfmkwle_MvMl __builtin_ve_vl_pvfmkwle_MvMl
#define _vel_pvfmkwnum_Mvl __builtin_ve_vl_pvfmkwnum_Mvl
#define _vel_pvfmkwnum_MvMl __builtin_ve_vl_pvfmkwnum_MvMl
#define _vel_pvfmkwnan_Mvl __builtin_ve_vl_pvfmkwnan_Mvl
#define _vel_pvfmkwnan_MvMl __builtin_ve_vl_pvfmkwnan_MvMl
#define _vel_pvfmkwgtnan_Mvl __builtin_ve_vl_pvfmkwgtnan_Mvl
#define _vel_pvfmkwgtnan_MvMl __builtin_ve_vl_pvfmkwgtnan_MvMl
#define _vel_pvfmkwltnan_Mvl __builtin_ve_vl_pvfmkwltnan_Mvl
#define _vel_pvfmkwltnan_MvMl __builtin_ve_vl_pvfmkwltnan_MvMl
#define _vel_pvfmkwnenan_Mvl __builtin_ve_vl_pvfmkwnenan_Mvl
#define _vel_pvfmkwnenan_MvMl __builtin_ve_vl_pvfmkwnenan_MvMl
#define _vel_pvfmkweqnan_Mvl __builtin_ve_vl_pvfmkweqnan_Mvl
#define _vel_pvfmkweqnan_MvMl __builtin_ve_vl_pvfmkweqnan_MvMl
#define _vel_pvfmkwgenan_Mvl __builtin_ve_vl_pvfmkwgenan_Mvl
#define _vel_pvfmkwgenan_MvMl __builtin_ve_vl_pvfmkwgenan_MvMl
#define _vel_pvfmkwlenan_Mvl __builtin_ve_vl_pvfmkwlenan_Mvl
#define _vel_pvfmkwlenan_MvMl __builtin_ve_vl_pvfmkwlenan_MvMl
#define _vel_vfmkdgt_mvl __builtin_ve_vl_vfmkdgt_mvl
#define _vel_vfmkdgt_mvml __builtin_ve_vl_vfmkdgt_mvml
#define _vel_vfmkdlt_mvl __builtin_ve_vl_vfmkdlt_mvl
#define _vel_vfmkdlt_mvml __builtin_ve_vl_vfmkdlt_mvml
#define _vel_vfmkdne_mvl __builtin_ve_vl_vfmkdne_mvl
#define _vel_vfmkdne_mvml __builtin_ve_vl_vfmkdne_mvml
#define _vel_vfmkdeq_mvl __builtin_ve_vl_vfmkdeq_mvl
#define _vel_vfmkdeq_mvml __builtin_ve_vl_vfmkdeq_mvml
#define _vel_vfmkdge_mvl __builtin_ve_vl_vfmkdge_mvl
#define _vel_vfmkdge_mvml __builtin_ve_vl_vfmkdge_mvml
#define _vel_vfmkdle_mvl __builtin_ve_vl_vfmkdle_mvl
#define _vel_vfmkdle_mvml __builtin_ve_vl_vfmkdle_mvml
#define _vel_vfmkdnum_mvl __builtin_ve_vl_vfmkdnum_mvl
#define _vel_vfmkdnum_mvml __builtin_ve_vl_vfmkdnum_mvml
#define _vel_vfmkdnan_mvl __builtin_ve_vl_vfmkdnan_mvl
#define _vel_vfmkdnan_mvml __builtin_ve_vl_vfmkdnan_mvml
#define _vel_vfmkdgtnan_mvl __builtin_ve_vl_vfmkdgtnan_mvl
#define _vel_vfmkdgtnan_mvml __builtin_ve_vl_vfmkdgtnan_mvml
#define _vel_vfmkdltnan_mvl __builtin_ve_vl_vfmkdltnan_mvl
#define _vel_vfmkdltnan_mvml __builtin_ve_vl_vfmkdltnan_mvml
#define _vel_vfmkdnenan_mvl __builtin_ve_vl_vfmkdnenan_mvl
#define _vel_vfmkdnenan_mvml __builtin_ve_vl_vfmkdnenan_mvml
#define _vel_vfmkdeqnan_mvl __builtin_ve_vl_vfmkdeqnan_mvl
#define _vel_vfmkdeqnan_mvml __builtin_ve_vl_vfmkdeqnan_mvml
#define _vel_vfmkdgenan_mvl __builtin_ve_vl_vfmkdgenan_mvl
#define _vel_vfmkdgenan_mvml __builtin_ve_vl_vfmkdgenan_mvml
#define _vel_vfmkdlenan_mvl __builtin_ve_vl_vfmkdlenan_mvl
#define _vel_vfmkdlenan_mvml __builtin_ve_vl_vfmkdlenan_mvml
#define _vel_vfmksgt_mvl __builtin_ve_vl_vfmksgt_mvl
#define _vel_vfmksgt_mvml __builtin_ve_vl_vfmksgt_mvml
#define _vel_vfmkslt_mvl __builtin_ve_vl_vfmkslt_mvl
#define _vel_vfmkslt_mvml __builtin_ve_vl_vfmkslt_mvml
#define _vel_vfmksne_mvl __builtin_ve_vl_vfmksne_mvl
#define _vel_vfmksne_mvml __builtin_ve_vl_vfmksne_mvml
#define _vel_vfmkseq_mvl __builtin_ve_vl_vfmkseq_mvl
#define _vel_vfmkseq_mvml __builtin_ve_vl_vfmkseq_mvml
#define _vel_vfmksge_mvl __builtin_ve_vl_vfmksge_mvl
#define _vel_vfmksge_mvml __builtin_ve_vl_vfmksge_mvml
#define _vel_vfmksle_mvl __builtin_ve_vl_vfmksle_mvl
#define _vel_vfmksle_mvml __builtin_ve_vl_vfmksle_mvml
#define _vel_vfmksnum_mvl __builtin_ve_vl_vfmksnum_mvl
#define _vel_vfmksnum_mvml __builtin_ve_vl_vfmksnum_mvml
#define _vel_vfmksnan_mvl __builtin_ve_vl_vfmksnan_mvl
#define _vel_vfmksnan_mvml __builtin_ve_vl_vfmksnan_mvml
#define _vel_vfmksgtnan_mvl __builtin_ve_vl_vfmksgtnan_mvl
#define _vel_vfmksgtnan_mvml __builtin_ve_vl_vfmksgtnan_mvml
#define _vel_vfmksltnan_mvl __builtin_ve_vl_vfmksltnan_mvl
#define _vel_vfmksltnan_mvml __builtin_ve_vl_vfmksltnan_mvml
#define _vel_vfmksnenan_mvl __builtin_ve_vl_vfmksnenan_mvl
#define _vel_vfmksnenan_mvml __builtin_ve_vl_vfmksnenan_mvml
#define _vel_vfmkseqnan_mvl __builtin_ve_vl_vfmkseqnan_mvl
#define _vel_vfmkseqnan_mvml __builtin_ve_vl_vfmkseqnan_mvml
#define _vel_vfmksgenan_mvl __builtin_ve_vl_vfmksgenan_mvl
#define _vel_vfmksgenan_mvml __builtin_ve_vl_vfmksgenan_mvml
#define _vel_vfmkslenan_mvl __builtin_ve_vl_vfmkslenan_mvl
#define _vel_vfmkslenan_mvml __builtin_ve_vl_vfmkslenan_mvml
#define _vel_pvfmkslogt_mvl __builtin_ve_vl_pvfmkslogt_mvl
#define _vel_pvfmksupgt_mvl __builtin_ve_vl_pvfmksupgt_mvl
#define _vel_pvfmkslogt_mvml __builtin_ve_vl_pvfmkslogt_mvml
#define _vel_pvfmksupgt_mvml __builtin_ve_vl_pvfmksupgt_mvml
#define _vel_pvfmkslolt_mvl __builtin_ve_vl_pvfmkslolt_mvl
#define _vel_pvfmksuplt_mvl __builtin_ve_vl_pvfmksuplt_mvl
#define _vel_pvfmkslolt_mvml __builtin_ve_vl_pvfmkslolt_mvml
#define _vel_pvfmksuplt_mvml __builtin_ve_vl_pvfmksuplt_mvml
#define _vel_pvfmkslone_mvl __builtin_ve_vl_pvfmkslone_mvl
#define _vel_pvfmksupne_mvl __builtin_ve_vl_pvfmksupne_mvl
#define _vel_pvfmkslone_mvml __builtin_ve_vl_pvfmkslone_mvml
#define _vel_pvfmksupne_mvml __builtin_ve_vl_pvfmksupne_mvml
#define _vel_pvfmksloeq_mvl __builtin_ve_vl_pvfmksloeq_mvl
#define _vel_pvfmksupeq_mvl __builtin_ve_vl_pvfmksupeq_mvl
#define _vel_pvfmksloeq_mvml __builtin_ve_vl_pvfmksloeq_mvml
#define _vel_pvfmksupeq_mvml __builtin_ve_vl_pvfmksupeq_mvml
#define _vel_pvfmksloge_mvl __builtin_ve_vl_pvfmksloge_mvl
#define _vel_pvfmksupge_mvl __builtin_ve_vl_pvfmksupge_mvl
#define _vel_pvfmksloge_mvml __builtin_ve_vl_pvfmksloge_mvml
#define _vel_pvfmksupge_mvml __builtin_ve_vl_pvfmksupge_mvml
#define _vel_pvfmkslole_mvl __builtin_ve_vl_pvfmkslole_mvl
#define _vel_pvfmksuple_mvl __builtin_ve_vl_pvfmksuple_mvl
#define _vel_pvfmkslole_mvml __builtin_ve_vl_pvfmkslole_mvml
#define _vel_pvfmksuple_mvml __builtin_ve_vl_pvfmksuple_mvml
#define _vel_pvfmkslonum_mvl __builtin_ve_vl_pvfmkslonum_mvl
#define _vel_pvfmksupnum_mvl __builtin_ve_vl_pvfmksupnum_mvl
#define _vel_pvfmkslonum_mvml __builtin_ve_vl_pvfmkslonum_mvml
#define _vel_pvfmksupnum_mvml __builtin_ve_vl_pvfmksupnum_mvml
#define _vel_pvfmkslonan_mvl __builtin_ve_vl_pvfmkslonan_mvl
#define _vel_pvfmksupnan_mvl __builtin_ve_vl_pvfmksupnan_mvl
#define _vel_pvfmkslonan_mvml __builtin_ve_vl_pvfmkslonan_mvml
#define _vel_pvfmksupnan_mvml __builtin_ve_vl_pvfmksupnan_mvml
#define _vel_pvfmkslogtnan_mvl __builtin_ve_vl_pvfmkslogtnan_mvl
#define _vel_pvfmksupgtnan_mvl __builtin_ve_vl_pvfmksupgtnan_mvl
#define _vel_pvfmkslogtnan_mvml __builtin_ve_vl_pvfmkslogtnan_mvml
#define _vel_pvfmksupgtnan_mvml __builtin_ve_vl_pvfmksupgtnan_mvml
#define _vel_pvfmksloltnan_mvl __builtin_ve_vl_pvfmksloltnan_mvl
#define _vel_pvfmksupltnan_mvl __builtin_ve_vl_pvfmksupltnan_mvl
#define _vel_pvfmksloltnan_mvml __builtin_ve_vl_pvfmksloltnan_mvml
#define _vel_pvfmksupltnan_mvml __builtin_ve_vl_pvfmksupltnan_mvml
#define _vel_pvfmkslonenan_mvl __builtin_ve_vl_pvfmkslonenan_mvl
#define _vel_pvfmksupnenan_mvl __builtin_ve_vl_pvfmksupnenan_mvl
#define _vel_pvfmkslonenan_mvml __builtin_ve_vl_pvfmkslonenan_mvml
#define _vel_pvfmksupnenan_mvml __builtin_ve_vl_pvfmksupnenan_mvml
#define _vel_pvfmksloeqnan_mvl __builtin_ve_vl_pvfmksloeqnan_mvl
#define _vel_pvfmksupeqnan_mvl __builtin_ve_vl_pvfmksupeqnan_mvl
#define _vel_pvfmksloeqnan_mvml __builtin_ve_vl_pvfmksloeqnan_mvml
#define _vel_pvfmksupeqnan_mvml __builtin_ve_vl_pvfmksupeqnan_mvml
#define _vel_pvfmkslogenan_mvl __builtin_ve_vl_pvfmkslogenan_mvl
#define _vel_pvfmksupgenan_mvl __builtin_ve_vl_pvfmksupgenan_mvl
#define _vel_pvfmkslogenan_mvml __builtin_ve_vl_pvfmkslogenan_mvml
#define _vel_pvfmksupgenan_mvml __builtin_ve_vl_pvfmksupgenan_mvml
#define _vel_pvfmkslolenan_mvl __builtin_ve_vl_pvfmkslolenan_mvl
#define _vel_pvfmksuplenan_mvl __builtin_ve_vl_pvfmksuplenan_mvl
#define _vel_pvfmkslolenan_mvml __builtin_ve_vl_pvfmkslolenan_mvml
#define _vel_pvfmksuplenan_mvml __builtin_ve_vl_pvfmksuplenan_mvml
#define _vel_pvfmksgt_Mvl __builtin_ve_vl_pvfmksgt_Mvl
#define _vel_pvfmksgt_MvMl __builtin_ve_vl_pvfmksgt_MvMl
#define _vel_pvfmkslt_Mvl __builtin_ve_vl_pvfmkslt_Mvl
#define _vel_pvfmkslt_MvMl __builtin_ve_vl_pvfmkslt_MvMl
#define _vel_pvfmksne_Mvl __builtin_ve_vl_pvfmksne_Mvl
#define _vel_pvfmksne_MvMl __builtin_ve_vl_pvfmksne_MvMl
#define _vel_pvfmkseq_Mvl __builtin_ve_vl_pvfmkseq_Mvl
#define _vel_pvfmkseq_MvMl __builtin_ve_vl_pvfmkseq_MvMl
#define _vel_pvfmksge_Mvl __builtin_ve_vl_pvfmksge_Mvl
#define _vel_pvfmksge_MvMl __builtin_ve_vl_pvfmksge_MvMl
#define _vel_pvfmksle_Mvl __builtin_ve_vl_pvfmksle_Mvl
#define _vel_pvfmksle_MvMl __builtin_ve_vl_pvfmksle_MvMl
#define _vel_pvfmksnum_Mvl __builtin_ve_vl_pvfmksnum_Mvl
#define _vel_pvfmksnum_MvMl __builtin_ve_vl_pvfmksnum_MvMl
#define _vel_pvfmksnan_Mvl __builtin_ve_vl_pvfmksnan_Mvl
#define _vel_pvfmksnan_MvMl __builtin_ve_vl_pvfmksnan_MvMl
#define _vel_pvfmksgtnan_Mvl __builtin_ve_vl_pvfmksgtnan_Mvl
#define _vel_pvfmksgtnan_MvMl __builtin_ve_vl_pvfmksgtnan_MvMl
#define _vel_pvfmksltnan_Mvl __builtin_ve_vl_pvfmksltnan_Mvl
#define _vel_pvfmksltnan_MvMl __builtin_ve_vl_pvfmksltnan_MvMl
#define _vel_pvfmksnenan_Mvl __builtin_ve_vl_pvfmksnenan_Mvl
#define _vel_pvfmksnenan_MvMl __builtin_ve_vl_pvfmksnenan_MvMl
#define _vel_pvfmkseqnan_Mvl __builtin_ve_vl_pvfmkseqnan_Mvl
#define _vel_pvfmkseqnan_MvMl __builtin_ve_vl_pvfmkseqnan_MvMl
#define _vel_pvfmksgenan_Mvl __builtin_ve_vl_pvfmksgenan_Mvl
#define _vel_pvfmksgenan_MvMl __builtin_ve_vl_pvfmksgenan_MvMl
#define _vel_pvfmkslenan_Mvl __builtin_ve_vl_pvfmkslenan_Mvl
#define _vel_pvfmkslenan_MvMl __builtin_ve_vl_pvfmkslenan_MvMl
#define _vel_vsumwsx_vvl __builtin_ve_vl_vsumwsx_vvl
#define _vel_vsumwsx_vvml __builtin_ve_vl_vsumwsx_vvml
#define _vel_vsumwzx_vvl __builtin_ve_vl_vsumwzx_vvl
#define _vel_vsumwzx_vvml __builtin_ve_vl_vsumwzx_vvml
#define _vel_vsuml_vvl __builtin_ve_vl_vsuml_vvl
#define _vel_vsuml_vvml __builtin_ve_vl_vsuml_vvml
#define _vel_vfsumd_vvl __builtin_ve_vl_vfsumd_vvl
#define _vel_vfsumd_vvml __builtin_ve_vl_vfsumd_vvml
#define _vel_vfsums_vvl __builtin_ve_vl_vfsums_vvl
#define _vel_vfsums_vvml __builtin_ve_vl_vfsums_vvml
#define _vel_vrmaxswfstsx_vvl __builtin_ve_vl_vrmaxswfstsx_vvl
#define _vel_vrmaxswfstsx_vvvl __builtin_ve_vl_vrmaxswfstsx_vvvl
#define _vel_vrmaxswlstsx_vvl __builtin_ve_vl_vrmaxswlstsx_vvl
#define _vel_vrmaxswlstsx_vvvl __builtin_ve_vl_vrmaxswlstsx_vvvl
#define _vel_vrmaxswfstzx_vvl __builtin_ve_vl_vrmaxswfstzx_vvl
#define _vel_vrmaxswfstzx_vvvl __builtin_ve_vl_vrmaxswfstzx_vvvl
#define _vel_vrmaxswlstzx_vvl __builtin_ve_vl_vrmaxswlstzx_vvl
#define _vel_vrmaxswlstzx_vvvl __builtin_ve_vl_vrmaxswlstzx_vvvl
#define _vel_vrminswfstsx_vvl __builtin_ve_vl_vrminswfstsx_vvl
#define _vel_vrminswfstsx_vvvl __builtin_ve_vl_vrminswfstsx_vvvl
#define _vel_vrminswlstsx_vvl __builtin_ve_vl_vrminswlstsx_vvl
#define _vel_vrminswlstsx_vvvl __builtin_ve_vl_vrminswlstsx_vvvl
#define _vel_vrminswfstzx_vvl __builtin_ve_vl_vrminswfstzx_vvl
#define _vel_vrminswfstzx_vvvl __builtin_ve_vl_vrminswfstzx_vvvl
#define _vel_vrminswlstzx_vvl __builtin_ve_vl_vrminswlstzx_vvl
#define _vel_vrminswlstzx_vvvl __builtin_ve_vl_vrminswlstzx_vvvl
#define _vel_vrmaxslfst_vvl __builtin_ve_vl_vrmaxslfst_vvl
#define _vel_vrmaxslfst_vvvl __builtin_ve_vl_vrmaxslfst_vvvl
#define _vel_vrmaxsllst_vvl __builtin_ve_vl_vrmaxsllst_vvl
#define _vel_vrmaxsllst_vvvl __builtin_ve_vl_vrmaxsllst_vvvl
#define _vel_vrminslfst_vvl __builtin_ve_vl_vrminslfst_vvl
#define _vel_vrminslfst_vvvl __builtin_ve_vl_vrminslfst_vvvl
#define _vel_vrminsllst_vvl __builtin_ve_vl_vrminsllst_vvl
#define _vel_vrminsllst_vvvl __builtin_ve_vl_vrminsllst_vvvl
#define _vel_vfrmaxdfst_vvl __builtin_ve_vl_vfrmaxdfst_vvl
#define _vel_vfrmaxdfst_vvvl __builtin_ve_vl_vfrmaxdfst_vvvl
#define _vel_vfrmaxdlst_vvl __builtin_ve_vl_vfrmaxdlst_vvl
#define _vel_vfrmaxdlst_vvvl __builtin_ve_vl_vfrmaxdlst_vvvl
#define _vel_vfrmaxsfst_vvl __builtin_ve_vl_vfrmaxsfst_vvl
#define _vel_vfrmaxsfst_vvvl __builtin_ve_vl_vfrmaxsfst_vvvl
#define _vel_vfrmaxslst_vvl __builtin_ve_vl_vfrmaxslst_vvl
#define _vel_vfrmaxslst_vvvl __builtin_ve_vl_vfrmaxslst_vvvl
#define _vel_vfrmindfst_vvl __builtin_ve_vl_vfrmindfst_vvl
#define _vel_vfrmindfst_vvvl __builtin_ve_vl_vfrmindfst_vvvl
#define _vel_vfrmindlst_vvl __builtin_ve_vl_vfrmindlst_vvl
#define _vel_vfrmindlst_vvvl __builtin_ve_vl_vfrmindlst_vvvl
#define _vel_vfrminsfst_vvl __builtin_ve_vl_vfrminsfst_vvl
#define _vel_vfrminsfst_vvvl __builtin_ve_vl_vfrminsfst_vvvl
#define _vel_vfrminslst_vvl __builtin_ve_vl_vfrminslst_vvl
#define _vel_vfrminslst_vvvl __builtin_ve_vl_vfrminslst_vvvl
#define _vel_vrand_vvl __builtin_ve_vl_vrand_vvl
#define _vel_vrand_vvml __builtin_ve_vl_vrand_vvml
#define _vel_vror_vvl __builtin_ve_vl_vror_vvl
#define _vel_vror_vvml __builtin_ve_vl_vror_vvml
#define _vel_vrxor_vvl __builtin_ve_vl_vrxor_vvl
#define _vel_vrxor_vvml __builtin_ve_vl_vrxor_vvml
#define _vel_vgt_vvssl __builtin_ve_vl_vgt_vvssl
#define _vel_vgt_vvssvl __builtin_ve_vl_vgt_vvssvl
#define _vel_vgt_vvssml __builtin_ve_vl_vgt_vvssml
#define _vel_vgt_vvssmvl __builtin_ve_vl_vgt_vvssmvl
#define _vel_vgtnc_vvssl __builtin_ve_vl_vgtnc_vvssl
#define _vel_vgtnc_vvssvl __builtin_ve_vl_vgtnc_vvssvl
#define _vel_vgtnc_vvssml __builtin_ve_vl_vgtnc_vvssml
#define _vel_vgtnc_vvssmvl __builtin_ve_vl_vgtnc_vvssmvl
#define _vel_vgtu_vvssl __builtin_ve_vl_vgtu_vvssl
#define _vel_vgtu_vvssvl __builtin_ve_vl_vgtu_vvssvl
#define _vel_vgtu_vvssml __builtin_ve_vl_vgtu_vvssml
#define _vel_vgtu_vvssmvl __builtin_ve_vl_vgtu_vvssmvl
#define _vel_vgtunc_vvssl __builtin_ve_vl_vgtunc_vvssl
#define _vel_vgtunc_vvssvl __builtin_ve_vl_vgtunc_vvssvl
#define _vel_vgtunc_vvssml __builtin_ve_vl_vgtunc_vvssml
#define _vel_vgtunc_vvssmvl __builtin_ve_vl_vgtunc_vvssmvl
#define _vel_vgtlsx_vvssl __builtin_ve_vl_vgtlsx_vvssl
#define _vel_vgtlsx_vvssvl __builtin_ve_vl_vgtlsx_vvssvl
#define _vel_vgtlsx_vvssml __builtin_ve_vl_vgtlsx_vvssml
#define _vel_vgtlsx_vvssmvl __builtin_ve_vl_vgtlsx_vvssmvl
#define _vel_vgtlsxnc_vvssl __builtin_ve_vl_vgtlsxnc_vvssl
#define _vel_vgtlsxnc_vvssvl __builtin_ve_vl_vgtlsxnc_vvssvl
#define _vel_vgtlsxnc_vvssml __builtin_ve_vl_vgtlsxnc_vvssml
#define _vel_vgtlsxnc_vvssmvl __builtin_ve_vl_vgtlsxnc_vvssmvl
#define _vel_vgtlzx_vvssl __builtin_ve_vl_vgtlzx_vvssl
#define _vel_vgtlzx_vvssvl __builtin_ve_vl_vgtlzx_vvssvl
#define _vel_vgtlzx_vvssml __builtin_ve_vl_vgtlzx_vvssml
#define _vel_vgtlzx_vvssmvl __builtin_ve_vl_vgtlzx_vvssmvl
#define _vel_vgtlzxnc_vvssl __builtin_ve_vl_vgtlzxnc_vvssl
#define _vel_vgtlzxnc_vvssvl __builtin_ve_vl_vgtlzxnc_vvssvl
#define _vel_vgtlzxnc_vvssml __builtin_ve_vl_vgtlzxnc_vvssml
#define _vel_vgtlzxnc_vvssmvl __builtin_ve_vl_vgtlzxnc_vvssmvl
#define _vel_vsc_vvssl __builtin_ve_vl_vsc_vvssl
#define _vel_vsc_vvssml __builtin_ve_vl_vsc_vvssml
#define _vel_vscnc_vvssl __builtin_ve_vl_vscnc_vvssl
#define _vel_vscnc_vvssml __builtin_ve_vl_vscnc_vvssml
#define _vel_vscot_vvssl __builtin_ve_vl_vscot_vvssl
#define _vel_vscot_vvssml __builtin_ve_vl_vscot_vvssml
#define _vel_vscncot_vvssl __builtin_ve_vl_vscncot_vvssl
#define _vel_vscncot_vvssml __builtin_ve_vl_vscncot_vvssml
#define _vel_vscu_vvssl __builtin_ve_vl_vscu_vvssl
#define _vel_vscu_vvssml __builtin_ve_vl_vscu_vvssml
#define _vel_vscunc_vvssl __builtin_ve_vl_vscunc_vvssl
#define _vel_vscunc_vvssml __builtin_ve_vl_vscunc_vvssml
#define _vel_vscuot_vvssl __builtin_ve_vl_vscuot_vvssl
#define _vel_vscuot_vvssml __builtin_ve_vl_vscuot_vvssml
#define _vel_vscuncot_vvssl __builtin_ve_vl_vscuncot_vvssl
#define _vel_vscuncot_vvssml __builtin_ve_vl_vscuncot_vvssml
#define _vel_vscl_vvssl __builtin_ve_vl_vscl_vvssl
#define _vel_vscl_vvssml __builtin_ve_vl_vscl_vvssml
#define _vel_vsclnc_vvssl __builtin_ve_vl_vsclnc_vvssl
#define _vel_vsclnc_vvssml __builtin_ve_vl_vsclnc_vvssml
#define _vel_vsclot_vvssl __builtin_ve_vl_vsclot_vvssl
#define _vel_vsclot_vvssml __builtin_ve_vl_vsclot_vvssml
#define _vel_vsclncot_vvssl __builtin_ve_vl_vsclncot_vvssl
#define _vel_vsclncot_vvssml __builtin_ve_vl_vsclncot_vvssml
#define _vel_andm_mmm __builtin_ve_vl_andm_mmm
#define _vel_andm_MMM __builtin_ve_vl_andm_MMM
#define _vel_orm_mmm __builtin_ve_vl_orm_mmm
#define _vel_orm_MMM __builtin_ve_vl_orm_MMM
#define _vel_xorm_mmm __builtin_ve_vl_xorm_mmm
#define _vel_xorm_MMM __builtin_ve_vl_xorm_MMM
#define _vel_eqvm_mmm __builtin_ve_vl_eqvm_mmm
#define _vel_eqvm_MMM __builtin_ve_vl_eqvm_MMM
#define _vel_nndm_mmm __builtin_ve_vl_nndm_mmm
#define _vel_nndm_MMM __builtin_ve_vl_nndm_MMM
#define _vel_negm_mm __builtin_ve_vl_negm_mm
#define _vel_negm_MM __builtin_ve_vl_negm_MM
#define _vel_pcvm_sml __builtin_ve_vl_pcvm_sml
#define _vel_lzvm_sml __builtin_ve_vl_lzvm_sml
#define _vel_tovm_sml __builtin_ve_vl_tovm_sml
#define _vel_lcr_sss __builtin_ve_vl_lcr_sss
#define _vel_scr_sss __builtin_ve_vl_scr_sss
#define _vel_tscr_ssss __builtin_ve_vl_tscr_ssss
#define _vel_fidcr_sss __builtin_ve_vl_fidcr_sss
#define _vel_fencei __builtin_ve_vl_fencei
#define _vel_fencem_s __builtin_ve_vl_fencem_s
#define _vel_fencec_s __builtin_ve_vl_fencec_s
#define _vel_svob __builtin_ve_vl_svob
